%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                                                                  %%%%%
%%%%    IEEE PES Power Grid Library - Optimal Power Flow - v18.08     %%%%%
%%%%          (https://github.com/power-grid-lib/pglib-opf)           %%%%%
%%%%               Benchmark Group - Typical Operations               %%%%%
%%%%                        08 - August - 2018                        %%%%%
%%%%                                                                  %%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   This is an entirely synthetic 500 bus case, geographically situated
%   in the northwestern part of the US state of South Carolina. The case is
%   designed with a 345 and 138 kV transmission network to serve
%   a load that roughly mimics the actual population of its geographic
%   footprint. The synthetic transmission system was designed by
%   algorithms described in [1] to be statistically similar to actual
%   transmission system models but without modeling any actual lines.
%
%   When publishing results based on this data, please cite:
%
%   [1] A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye, T.J. Overbye,
%       "Grid Structural Characteristics as Validation Criteria for
%       Synthetic Networks," IEEE Transactions on Power Systems, 2017.
%
%   This is a synthetic power system model that does not represent the
%   actual grid. It was developed as part of the US ARPA-E GRID DATA
%   research project and contains no CEII.
%
%   One-line diagrams and other data formats available at:
%       https://electricgrids.engr.tamu.edu
%
%   May 16, 2017
%
%   Created from ACTIV_SG_500.pwb, saved by
%   PowerWorld Simulator, version 20 Beta, build date May 19, 2017,
%   then by MATPOWER 6.
%
%   Copyright (c) 2017 by A.B. Birchfield, T. Xu, K.M. Gegner, K.S. Shetye,
%   and T.J. Overbye
%   Licensed under the Creative Commons Attribution 4.0 International license,
%   http://creativecommons.org/licenses/by/4.0/
%
function mpc = pglib_opf_case500_tamu
mpc.version = '2';
mpc.baseMVA = 100.0;

%% bus data
%	bus_i	type	Pd	Qd	Gs	Bs	area	Vm	Va	baseKV	zone	Vmax	Vmin
mpc.bus = [
	1	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	2	 1	 42.8	 11.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	3	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	4	 1	 132.69	 35.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	5	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	6	 1	 3.21	 0.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	7	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	8	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	9	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	10	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	11	 1	 2.47	 0.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	12	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	13	 1	 37.16	 9.91	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	14	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	15	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	16	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	17	 3	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	18	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	19	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	20	 1	 4.54	 1.21	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	21	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	22	 1	 148.7	 39.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	23	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	24	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	25	 1	 2.28	 0.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	26	 1	 21.66	 5.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	27	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	28	 1	 62.93	 16.78	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	29	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	30	 1	 99.97	 26.66	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	31	 1	 0.0	 0.0	 0.0	 100.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	32	 1	 9.76	 2.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	33	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	34	 1	 25.0	 6.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	35	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	36	 1	 43.35	 11.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	37	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	38	 1	 0.13	 0.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	39	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	40	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	41	 1	 57.99	 15.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	42	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	43	 1	 4.46	 1.19	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	44	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	45	 1	 2.03	 0.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	46	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	47	 1	 43.41	 11.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	48	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	49	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	50	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	51	 1	 0.35	 0.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	52	 1	 23.39	 6.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	53	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	54	 1	 34.81	 9.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	55	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	56	 1	 2.25	 0.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	57	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	58	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	59	 1	 140.94	 37.58	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	60	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	61	 1	 0.2	 0.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	62	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	63	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	64	 1	 34.78	 9.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	65	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	66	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	67	 1	 4.57	 1.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	68	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	69	 1	 16.96	 4.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	70	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	71	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	72	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	73	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	74	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	75	 1	 5.3	 1.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	76	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	77	 1	 6.95	 1.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	78	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	79	 1	 0.38	 0.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	80	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	81	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	82	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	83	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	84	 1	 61.41	 16.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	85	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	86	 1	 17.59	 4.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	87	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	88	 1	 5.25	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	89	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	90	 1	 5.9	 1.57	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	91	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	92	 1	 65.03	 17.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	93	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	94	 1	 5.21	 1.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	95	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	96	 1	 34.0	 9.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	97	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	98	 1	 37.09	 9.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	99	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	100	 1	 13.52	 3.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	101	 1	 0.89	 0.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	102	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	103	 1	 38.8	 10.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	104	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	105	 1	 80.33	 21.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	106	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	107	 1	 16.01	 4.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	108	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	109	 1	 47.58	 12.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	110	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	111	 1	 62.29	 16.61	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	112	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	113	 1	 45.99	 12.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	114	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	115	 1	 5.06	 1.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	116	 1	 3.1	 0.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	117	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	118	 1	 8.83	 2.36	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	119	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	120	 1	 31.65	 8.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	121	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	122	 1	 53.36	 14.23	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	123	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	124	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	125	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	126	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	127	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	128	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	129	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	130	 1	 103.24	 27.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	131	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	132	 1	 25.2	 6.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	133	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	134	 1	 42.65	 11.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	135	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	136	 1	 26.76	 7.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	137	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	138	 1	 78.71	 20.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	139	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	140	 1	 0.26	 0.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	141	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	142	 1	 161.34	 43.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	143	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	144	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	145	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	146	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	147	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	148	 1	 57.42	 15.31	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	149	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	150	 1	 1.5	 0.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	151	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	152	 1	 0.0	 0.0	 0.0	 70.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	153	 1	 93.15	 24.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	154	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	155	 1	 66.84	 17.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	156	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	157	 1	 105.45	 28.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	158	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	159	 1	 22.85	 6.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	160	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	161	 1	 25.95	 6.92	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	162	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	163	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	164	 1	 98.15	 26.17	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	165	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	166	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	167	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	168	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	169	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	170	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	171	 1	 12.38	 3.3	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	172	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	173	 1	 3.14	 0.84	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	174	 1	 7.3	 1.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	175	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	176	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	177	 1	 8.78	 2.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	178	 1	 6.81	 1.82	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	179	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	180	 1	 14.14	 3.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	181	 1	 0.0	 0.0	 0.0	 60.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	182	 1	 82.61	 22.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	183	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	184	 1	 30.18	 8.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	185	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	186	 1	 45.35	 12.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	187	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	188	 1	 11.05	 2.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	189	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	190	 1	 14.07	 3.75	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	191	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	192	 1	 16.44	 4.38	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	193	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	194	 1	 28.69	 7.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	195	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	196	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	197	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	198	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	199	 1	 86.39	 23.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	200	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	201	 1	 8.89	 2.37	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	202	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	203	 1	 4.69	 1.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	204	 1	 45.67	 12.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	205	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	206	 1	 3.01	 0.8	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	207	 1	 22.57	 6.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	208	 1	 0.0	 0.0	 0.0	 80.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	209	 1	 81.85	 21.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	210	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	211	 1	 34.28	 9.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	212	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	213	 1	 97.48	 26.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	214	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	215	 1	 84.48	 22.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	216	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	217	 1	 55.1	 14.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	218	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	219	 1	 0.33	 0.09	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	220	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	221	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	222	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	223	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	224	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	225	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	226	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	227	 1	 5.42	 1.45	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	228	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	229	 1	 54.09	 14.42	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	230	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	231	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	232	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	233	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	234	 1	 59.96	 15.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	235	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	236	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	237	 1	 2.71	 0.72	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	238	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	239	 1	 39.13	 10.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	240	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	241	 1	 19.74	 5.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	242	 1	 0.0	 0.0	 0.0	 70.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	243	 1	 74.47	 19.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	244	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	245	 1	 11.83	 3.16	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	246	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	247	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	248	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	249	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	250	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	251	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	252	 1	 118.68	 31.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	253	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	254	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	255	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	256	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	257	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	258	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	259	 1	 8.16	 2.18	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	260	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	261	 1	 18.68	 4.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	262	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	263	 1	 0.0	 0.0	 0.0	 120.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	264	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	265	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	266	 1	 61.78	 16.48	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	267	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	268	 1	 117.15	 31.24	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	269	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	270	 1	 6.8	 1.81	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	271	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	272	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	273	 1	 9.49	 2.53	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	274	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	275	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	276	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	277	 1	 0.41	 0.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	278	 1	 5.77	 1.54	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	279	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	280	 1	 16.94	 4.52	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	281	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	282	 1	 117.3	 31.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	283	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	284	 1	 32.65	 8.71	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	285	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	286	 1	 8.27	 2.2	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	287	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	288	 1	 58.11	 15.5	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	289	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	290	 1	 3.69	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	291	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	292	 1	 7.62	 2.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	293	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	294	 1	 25.6	 6.83	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	295	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	296	 1	 7.79	 2.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	297	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	298	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	299	 1	 14.57	 3.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	300	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	301	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	302	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	303	 1	 86.76	 23.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	304	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	305	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	306	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	307	 1	 76.04	 20.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	308	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	309	 1	 9.03	 2.41	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	310	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	311	 1	 43.83	 11.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	312	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	313	 1	 12.44	 3.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	314	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	315	 1	 0.43	 0.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	316	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	317	 1	 3.75	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	318	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	319	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	320	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	321	 1	 150.42	 40.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	322	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	323	 1	 45.27	 12.07	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	324	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	325	 1	 103.46	 27.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	326	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	327	 1	 121.07	 32.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	328	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	329	 1	 26.02	 6.94	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	330	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	331	 1	 57.17	 15.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	332	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	333	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	334	 1	 0.5	 0.13	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	335	 1	 0.83	 0.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	336	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	337	 1	 5.67	 1.51	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	338	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	339	 1	 75.1	 20.03	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	340	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	341	 1	 24.22	 6.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	342	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	343	 1	 2.51	 0.67	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	344	 1	 2.43	 0.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	345	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	346	 1	 47.58	 12.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	347	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	348	 1	 86.4	 23.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	349	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	350	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	351	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	352	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	353	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	354	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	355	 1	 19.97	 5.32	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	356	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	357	 1	 55.73	 14.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	358	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	359	 1	 14.59	 3.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	360	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	361	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	362	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	363	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	364	 1	 30.44	 8.12	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	365	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	366	 1	 56.49	 15.06	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	367	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	368	 1	 11.45	 3.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	369	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	370	 1	 35.6	 9.49	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	371	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	372	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	373	 1	 28.84	 7.69	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	374	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	375	 1	 24.76	 6.6	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	376	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	377	 1	 90.39	 24.1	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	378	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	379	 1	 13.01	 3.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	380	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	381	 1	 10.13	 2.7	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	382	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	383	 1	 29.95	 7.99	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	384	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	385	 1	 36.62	 9.77	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	386	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	387	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	388	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	389	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	390	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	391	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	392	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	393	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	394	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	395	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	396	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	397	 1	 39.95	 10.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	398	 1	 16.77	 4.47	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	399	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	400	 1	 23.03	 6.14	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	401	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	402	 1	 88.35	 23.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	403	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	404	 1	 19.77	 5.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	405	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	406	 1	 5.25	 1.4	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	407	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	408	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	409	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	410	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	411	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	412	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	413	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	414	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	415	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	416	 1	 6.06	 1.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	417	 1	 0.0	 0.0	 0.0	 110.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	418	 1	 63.62	 16.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	419	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	420	 1	 5.23	 1.39	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	421	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	422	 1	 49.18	 13.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	423	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	424	 1	 157.1	 41.89	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	425	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	426	 1	 0.0	 0.0	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	427	 1	 14.43	 3.85	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	428	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	429	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	430	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	431	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	432	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	433	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	434	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	435	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	436	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	437	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	438	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	439	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	440	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	441	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	442	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	443	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	444	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	445	 1	 0.0	 0.0	 0.0	 40.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	446	 1	 88.68	 23.65	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	447	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	448	 1	 57.56	 15.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	449	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	450	 1	 1.12	 0.3	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	451	 1	 2.21	 0.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	452	 1	 11.16	 2.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	453	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 2	    1.10000	    0.90000;
	454	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	455	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	456	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	457	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	458	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	459	 1	 74.47	 19.86	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	460	 1	 26.34	 7.02	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	461	 1	 91.72	 24.46	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	462	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	463	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	464	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	465	 1	 12.52	 3.34	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	466	 1	 43.34	 11.56	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	467	 1	 0.81	 0.22	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	468	 1	 3.76	 1.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	469	 1	 128.53	 34.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	470	 1	 42.56	 11.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	471	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 345.0	 1	    1.10000	    0.90000;
	472	 1	 49.71	 13.26	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	473	 1	 1.0	 0.27	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	474	 1	 167.22	 44.59	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	475	 1	 0.16	 0.04	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	476	 1	 59.86	 15.96	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	477	 1	 31.33	 8.35	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	478	 1	 9.16	 2.44	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	479	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	480	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	481	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	482	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	483	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	484	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 2	    1.10000	    0.90000;
	485	 1	 27.88	 7.43	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	486	 1	 68.54	 18.28	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	487	 1	 11.67	 3.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	488	 1	 97.9	 26.11	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	489	 1	 3.68	 0.98	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	490	 1	 29.81	 7.95	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	491	 1	 119.53	 31.87	 0.0	 50.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	492	 1	 59.54	 15.88	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	493	 1	 4.05	 1.08	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	494	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	495	 1	 75.17	 20.05	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	496	 1	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 1	    1.10000	    0.90000;
	497	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	498	 2	 0.0	 0.0	 0.0	 0.0	 1	    1.00000	    0.00000	 13.8	 1	    1.10000	    0.90000;
	499	 1	 122.33	 32.62	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
	500	 1	 23.43	 6.25	 0.0	 0.0	 1	    1.00000	    0.00000	 138.0	 2	    1.10000	    0.90000;
];

%% generator data
%	bus	Pg	Qg	Qmax	Qmin	Vg	mBase	status	Pmax	Pmin	Pc1	Pc2	Qc1min	Qc1max	Qc2min	Qc2max	ramp_agc	ramp_10	ramp_30	ramp_q	apf
mpc.gen = [
	9	 501.67	 132.75	 359.66	 -94.16	 1.04	 926.16	 1	 771.8	 231.54	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	16	 288.89	 63.56	 163.56	 -36.44	 1.04	 533.34	 1	 444.45	 133.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	17	 577.785	 127.115	 327.12	 -72.89	 1.04	 1066.68	 1	 888.9	 266.67	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	18	 102.44	 22.54	 58.0	 -12.92	 1.04	 189.12	 1	 157.6	 47.28	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	49	 0.845	 0.225	 0.61	 -0.16	 1.04	 1.56	 1	 1.3	 0.39	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	50	 1.69	 0.445	 1.21	 -0.32	 1.04	 3.12	 1	 2.6	 0.78	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	63	 2.08	 0.635	 1.63	 -0.36	 1.04	 3.84	 0	 3.2	 0.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	71	 2.6	 0.67	 1.54	 -0.2	 1.04	 4.8	 1	 4.0	 1.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	72	 1.3	 0.335	 0.77	 -0.1	 1.04	 2.4	 1	 2.0	 0.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	73	 0.91	 0.235	 0.54	 -0.07	 1.04	 1.68	 1	 1.4	 0.42	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	82	 235.235	 60.62	 138.97	 -17.73	 1.04	 434.28	 1	 361.9	 108.57	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	125	 105.3	 27.135	 62.21	 -7.94	 1.04	 194.4	 0	 162.0	 48.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	126	 105.3	 27.135	 62.21	 -7.94	 1.04	 194.4	 0	 162.0	 48.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	127	 105.3	 27.135	 62.21	 -7.94	 1.04	 194.4	 1	 162.0	 48.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	128	 105.3	 27.135	 62.21	 -7.94	 1.04	 194.4	 1	 162.0	 48.6	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	144	 391.655	 86.165	 221.74	 -49.41	 1.04	 723.06	 1	 602.55	 180.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	145	 391.655	 86.165	 221.74	 -49.41	 1.04	 723.06	 1	 602.55	 180.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	167	 125.775	 32.41	 74.3	 -9.48	 1.04	 232.2	 1	 193.5	 58.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	168	 125.775	 32.41	 74.3	 -9.48	 1.04	 232.2	 1	 193.5	 58.05	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	169	 251.55	 64.825	 148.61	 -18.96	 1.04	 464.4	 1	 387.0	 116.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	197	 190.84	 50.5	 136.82	 -35.82	 1.04	 352.32	 1	 293.6	 88.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	198	 134.745	 35.655	 96.6	 -25.29	 1.04	 248.76	 1	 207.3	 62.19	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	222	 3.38	 0.875	 2.0	 -0.25	 1.04	 6.24	 1	 5.2	 1.56	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	223	 11.7	 3.015	 6.91	 -0.88	 1.04	 21.6	 1	 18.0	 5.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	224	 332.28	 85.625	 196.3	 -25.05	 1.04	 613.44	 1	 511.2	 153.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	225	 334.62	 86.225	 197.68	 -25.23	 1.04	 617.76	 1	 514.8	 154.44	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	231	 1.885	 0.5	 1.35	 -0.35	 1.04	 3.48	 1	 2.9	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	248	 86.58	 26.505	 67.8	 -14.79	 1.04	 159.84	 0	 133.2	 39.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	249	 86.58	 26.505	 67.8	 -14.79	 1.04	 159.84	 0	 133.2	 39.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	250	 346.32	 106.03	 271.2	 -59.14	 1.04	 639.36	 0	 532.8	 159.84	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	254	 2.665	 0.705	 1.91	 -0.5	 1.04	 4.92	 0	 4.1	 1.23	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	255	 2.145	 0.57	 1.54	 -0.4	 1.04	 3.96	 0	 3.3	 0.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	256	 1.885	 0.5	 1.35	 -0.35	 1.04	 3.48	 0	 2.9	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	257	 3.51	 0.93	 2.52	 -0.66	 1.04	 6.48	 0	 5.4	 1.62	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	258	 0.715	 0.19	 0.51	 -0.13	 1.04	 1.32	 1	 1.1	 0.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	264	 25.48	 7.8	 19.95	 -4.35	 1.04	 47.04	 0	 39.2	 11.76	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	265	 6.89	 2.11	 5.4	 -1.18	 1.04	 12.72	 0	 10.6	 3.18	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	275	 65.78	 20.14	 51.51	 -11.23	 1.04	 121.44	 0	 101.2	 30.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	301	 1.885	 0.5	 1.35	 -0.35	 1.04	 3.48	 1	 2.9	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	302	 1.885	 0.5	 1.35	 -0.35	 1.04	 3.48	 1	 2.9	 0.87	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	305	 0.65	 0.165	 0.38	 -0.05	 1.04	 1.2	 1	 1.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	306	 1.56	 0.4	 0.92	 -0.12	 1.04	 2.88	 1	 2.4	 0.72	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	319	 27.495	 7.085	 16.24	 -2.07	 1.04	 50.76	 1	 42.3	 12.69	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	350	 9.75	 2.51	 5.76	 -0.74	 1.04	 18.0	 1	 15.0	 4.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	351	 4.03	 1.04	 2.38	 -0.3	 1.04	 7.44	 1	 6.2	 1.86	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	352	 9.36	 2.41	 5.53	 -0.71	 1.04	 17.28	 1	 14.4	 4.32	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	353	 48.1	 12.395	 28.42	 -3.63	 1.04	 88.8	 1	 74.0	 22.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	361	 1.04	 0.315	 0.81	 -0.18	 1.04	 1.92	 0	 1.6	 0.48	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	362	 7.15	 2.19	 5.6	 -1.22	 1.04	 13.2	 0	 11.0	 3.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	363	 2.08	 0.635	 1.63	 -0.36	 1.04	 3.84	 0	 3.2	 0.96	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	388	 6.5	 1.99	 5.09	 -1.11	 1.04	 12.0	 0	 10.0	 3.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	389	 112.665	 34.495	 88.23	 -19.24	 1.04	 208.0	 0	 173.33	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	390	 112.665	 34.495	 88.23	 -19.24	 1.04	 208.0	 0	 173.33	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	391	 112.665	 34.495	 88.23	 -19.24	 1.04	 208.0	 0	 173.33	 52.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	392	 75.66	 23.165	 59.25	 -12.92	 1.04	 139.68	 0	 116.4	 34.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	393	 75.66	 23.165	 59.25	 -12.92	 1.04	 139.68	 0	 116.4	 34.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	394	 75.66	 23.165	 59.25	 -12.92	 1.04	 139.68	 0	 116.4	 34.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	395	 75.66	 23.165	 59.25	 -12.92	 1.04	 139.68	 0	 116.4	 34.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	396	 75.66	 23.165	 59.25	 -12.92	 1.04	 139.68	 0	 116.4	 34.92	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	409	 65.0	 19.9	 50.9	 -11.1	 1.04	 120.0	 0	 100.0	 30.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	410	 89.015	 27.255	 69.71	 -15.2	 1.04	 164.34	 1	 136.95	 41.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	411	 89.015	 27.255	 69.71	 -15.2	 1.04	 164.34	 1	 136.95	 41.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	412	 89.015	 27.255	 69.71	 -15.2	 1.04	 164.34	 1	 136.95	 41.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	413	 89.015	 27.255	 69.71	 -15.2	 1.04	 164.34	 1	 136.95	 41.08	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	414	 72.215	 22.11	 56.55	 -12.33	 1.04	 133.32	 0	 111.1	 33.33	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	430	 0.65	 0.165	 0.38	 -0.05	 1.04	 1.2	 1	 1.0	 0.3	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	431	 2.145	 0.555	 1.27	 -0.16	 1.04	 3.96	 1	 3.3	 0.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	432	 0.78	 0.2	 0.46	 -0.06	 1.04	 1.44	 1	 1.2	 0.36	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	433	 4.355	 1.12	 2.57	 -0.33	 1.04	 8.04	 1	 6.7	 2.01	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	434	 2.795	 0.72	 1.65	 -0.21	 1.04	 5.16	 1	 4.3	 1.29	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	435	 128.05	 33.0	 75.65	 -9.65	 1.04	 236.4	 0	 197.0	 59.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	436	 128.05	 33.0	 75.65	 -9.65	 1.04	 236.4	 0	 197.0	 59.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	437	 128.05	 33.0	 75.65	 -9.65	 1.04	 236.4	 1	 197.0	 59.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	438	 128.05	 33.0	 75.65	 -9.65	 1.04	 236.4	 1	 197.0	 59.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	439	 128.05	 33.0	 75.65	 -9.65	 1.04	 236.4	 1	 197.0	 59.1	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	442	 70.2	 21.49	 54.97	 -11.99	 1.04	 129.6	 0	 108.0	 32.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	443	 113.75	 34.82	 89.07	 -19.43	 1.04	 210.0	 0	 175.0	 52.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	444	 2.145	 0.655	 1.68	 -0.37	 1.04	 3.96	 0	 3.3	 0.99	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	455	 144.84	 44.345	 113.42	 -24.73	 1.04	 267.4	 1	 222.83	 66.85	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	456	 289.685	 88.685	 226.84	 -49.47	 1.04	 534.8	 1	 445.67	 133.7	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	458	 71.24	 0.0	 0.0	 0.0	 1.04	 131.52	 1	 109.6	 32.88	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	463	 4.68	 1.24	 3.36	 -0.88	 1.04	 8.64	 0	 7.2	 2.16	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	480	 36.4	 9.38	 21.5	 -2.74	 1.04	 67.2	 1	 56.0	 16.8	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	481	 29.25	 7.535	 17.28	 -2.21	 1.04	 54.0	 1	 45.0	 13.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	482	 29.25	 7.535	 17.28	 -2.21	 1.04	 54.0	 1	 45.0	 13.5	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	483	 15.6	 4.02	 9.22	 -1.18	 1.04	 28.8	 1	 24.0	 7.2	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	484	 18.2	 4.69	 10.75	 -1.37	 1.04	 33.6	 1	 28.0	 8.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	494	 3.77	 0.995	 2.7	 -0.71	 1.04	 6.96	 0	 5.8	 1.74	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	497	 39.0	 10.05	 23.04	 -2.94	 1.04	 72.0	 1	 60.0	 18.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
	498	 11.7	 3.015	 6.91	 -0.88	 1.04	 21.6	 1	 18.0	 5.4	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0	 0.0;
];

%% generator cost data
%	2	startup	shutdown	n	c(n-1)	...	c0
mpc.gencost = [
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 1424.480000;
	2	 0.0	 0.0	 3	   0.000000	   5.867000	 1266.470000;
	2	 0.0	 0.0	 3	   0.000000	   8.412000	 1319.130000;
	2	 0.0	 0.0	 3	   0.000000	   9.275000	 1076.210000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.030000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.070000;
	2	 0.0	 0.0	 3	   0.002000	  23.152000	 604.800000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   6.870000	 1363.880000;
	2	 0.0	 0.0	 3	   0.000000	   8.143000	 1060.190000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 1081.020000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 879.080000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.080000;
	2	 0.0	 0.0	 3	   0.002000	  24.033000	 799.800000;
	2	 0.0	 0.0	 3	   0.002000	  24.033000	 799.800000;
	2	 0.0	 0.0	 3	   0.002000	  26.742000	 2763.980000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.110000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.090000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.080000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.140000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.030000;
	2	 0.0	 0.0	 3	   0.002000	  23.396000	 658.800000;
	2	 0.0	 0.0	 3	   0.002000	  23.202000	 615.900000;
	2	 0.0	 0.0	 3	   0.002000	  23.816000	 751.800000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.080000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.080000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.141000	 602.400000;
	2	 0.0	 0.0	 3	   0.002000	  23.205000	 616.500000;
	2	 0.0	 0.0	 3	   0.002000	  23.152000	 604.800000;
	2	 0.0	 0.0	 3	   0.002000	  23.198000	 615.000000;
	2	 0.0	 0.0	 3	   0.002000	  24.305000	 859.990000;
	2	 0.0	 0.0	 3	   0.002000	  24.305000	 859.990000;
	2	 0.0	 0.0	 3	   0.002000	  24.305000	 859.990000;
	2	 0.0	 0.0	 3	   0.002000	  23.919000	 774.600000;
	2	 0.0	 0.0	 3	   0.002000	  23.919000	 774.600000;
	2	 0.0	 0.0	 3	   0.002000	  23.919000	 774.600000;
	2	 0.0	 0.0	 3	   0.002000	  23.919000	 774.600000;
	2	 0.0	 0.0	 3	   0.002000	  23.919000	 774.600000;
	2	 0.0	 0.0	 3	   0.002000	  23.808000	 750.000000;
	2	 0.0	 0.0	 3	   0.002000	  24.059000	 805.420000;
	2	 0.0	 0.0	 3	   0.002000	  24.059000	 805.420000;
	2	 0.0	 0.0	 3	   0.002000	  24.059000	 805.420000;
	2	 0.0	 0.0	 3	   0.002000	  24.059000	 805.420000;
	2	 0.0	 0.0	 3	   0.002000	  23.883000	 766.650000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  23.862000	 762.000000;
	2	 0.0	 0.0	 3	   0.002000	  24.316000	 862.500000;
	2	 0.0	 0.0	 3	   0.002000	  23.152000	 604.950000;
	2	 0.0	 0.0	 3	   0.002000	  24.641000	 934.240000;
	2	 0.0	 0.0	 3	   0.002000	  26.152000	 1344.190000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.190000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.002000	  19.000000	 236.150000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
	2	 0.0	 0.0	 3	   0.000000	   0.000000	   0.000000;
];

%% branch data
%	fbus	tbus	r	x	b	rateA	rateB	rateC	ratio	angle	status	angmin	angmax
mpc.branch = [
	2	 1	 0.000531	 0.00314	 0.0	 76.5	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 1	 0.005479	 0.050257	 0.01781	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	421	 1	 0.005369	 0.051555	 0.01664	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	4	 3	 0.000692	 0.003518	 0.0	 225.06	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62	 3	 0.002718	 0.026098	 0.00842	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	3	 479	 0.007258	 0.069699	 0.0225	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	6	 5	 0.000556	 0.003563	 0.0	 4.49	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	316	 5	 0.002445	 0.02348	 0.00758	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	401	 5	 0.004886	 0.04692	 0.01515	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 7	 0.000355	 0.0129	 0.0	 567.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9	 7	 0.00012	 0.01362	 0.0	 680.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	9	 7	 0.00012	 0.01362	 0.0	 680.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	7	 232	 0.001119	 0.014808	 0.31205	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	7	 262	 0.000947	 0.013749	 0.23994	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 287	 0.003727	 0.035786	 0.01155	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	8	 457	 0.001974	 0.018955	 0.00612	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	11	 10	 0.000655	 0.003201	 0.0	 3.96	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	342	 10	 0.002825	 0.027123	 0.00876	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	10	 349	 0.001402	 0.01346	 0.00434	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	13	 12	 0.000623	 0.003134	 0.0	 65.5	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 216	 0.003962	 0.038048	 0.01228	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 304	 0.00231	 0.021191	 0.00751	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	12	 441	 0.001565	 0.015025	 0.00485	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 14	 0.000208	 0.01122	 0.0	 682.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	16	 14	 0.000326	 0.01202	 0.0	 596.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17	 14	 0.000279	 0.01438	 0.0	 674.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	17	 14	 0.000354	 0.01438	 0.0	 674.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	18	 14	 0.001417	 0.05115	 0.0	 340.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	386	 14	 0.000317	 0.004547	 0.08136	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	386	 14	 0.00032	 0.00455	 0.08136	 1493.9	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 91	 0.004799	 0.046085	 0.01488	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 230	 0.010894	 0.104607	 0.03377	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 15	 0.001918	 0.018416	 0.00594	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 369	 0.001854	 0.01701	 0.00603	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	15	 473	 0.009225	 0.084621	 0.02999	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	20	 19	 0.000541	 0.003886	 0.0	 7.53	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 112	 0.004722	 0.045345	 0.01464	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 19	 0.002221	 0.021323	 0.00688	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	19	 272	 0.002293	 0.02202	 0.00711	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	22	 21	 0.000587	 0.003174	 0.0	 254.15	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 112	 0.005092	 0.048896	 0.01578	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	21	 196	 0.002207	 0.020247	 0.00718	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 23	 0.00033	 0.01764	 0.0	 626.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	151	 23	 0.000182	 0.002607	 0.04665	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 386	 0.001642	 0.023851	 0.41623	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 464	 0.000947	 0.012532	 0.26411	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	23	 471	 0.000532	 0.007041	 0.14837	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	25	 24	 0.000613	 0.003629	 0.0	 3.56	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	26	 24	 0.000563	 0.003729	 0.0	 29.46	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	210	 24	 0.002218	 0.020344	 0.00721	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	24	 360	 0.002365	 0.022714	 0.00733	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	28	 27	 0.000687	 0.003963	 0.0	 108.61	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 68	 0.005607	 0.053845	 0.01738	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	27	 382	 0.00337	 0.030912	 0.01095	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	30	 29	 0.000616	 0.003298	 0.0	 156.98	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 29	 0.00247	 0.022656	 0.00803	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	29	 491	 0.005607	 0.053837	 0.01738	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	32	 31	 0.000625	 0.003429	 0.0	 15.7	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 85	 0.005303	 0.050926	 0.01644	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	104	 31	 0.005526	 0.053062	 0.01713	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 189	 0.005707	 0.0548	 0.01769	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 205	 0.007797	 0.074869	 0.02417	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	31	 218	 0.008273	 0.079446	 0.02565	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	267	 31	 0.004897	 0.047021	 0.01518	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	34	 33	 0.000624	 0.003284	 0.0	 43.35	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 33	 0.005287	 0.050764	 0.01639	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 33	 0.007061	 0.067808	 0.02189	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	36	 35	 0.000583	 0.00303	 0.0	 62.87	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 35	 0.004038	 0.037042	 0.01313	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	35	 399	 0.005636	 0.054123	 0.01747	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	38	 37	 0.000546	 0.003823	 0.0	 0.18	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	76	 37	 0.001474	 0.014156	 0.00457	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	37	 176	 0.003039	 0.02918	 0.00942	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 39	 0.0007	 0.02531	 0.0	 428.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	39	 332	 0.000403	 0.005786	 0.10355	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	39	 428	 0.000521	 0.006898	 0.14538	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	41	 40	 0.000631	 0.003923	 0.0	 97.47	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	40	 131	 0.002909	 0.026681	 0.00946	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	43	 42	 0.000542	 0.003119	 0.0	 7.7	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 42	 0.002361	 0.02166	 0.00768	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	42	 191	 0.006368	 0.05842	 0.0207	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	45	 44	 0.000637	 0.003876	 0.0	 2.84	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	44	 200	 0.002105	 0.019311	 0.00684	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	47	 46	 0.000602	 0.003454	 0.0	 63.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	46	 156	 0.006611	 0.063482	 0.02049	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 46	 0.003134	 0.030093	 0.00971	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	49	 48	 0.01331	 0.27853	 0.0	 57.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	50	 48	 0.00715	 0.16356	 0.0	 70.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	51	 48	 0.000658	 0.003672	 0.0	 0.56	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	52	 48	 0.00062	 0.003342	 0.0	 37.95	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	358	 48	 0.0045	 0.041283	 0.01463	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	419	 48	 0.004637	 0.044525	 0.01437	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	54	 53	 0.00068	 0.003061	 0.0	 51.27	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	233	 53	 0.002362	 0.021667	 0.00768	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	53	 276	 0.001502	 0.014424	 0.00466	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	56	 55	 0.000641	 0.00331	 0.0	 3.15	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 66	 0.00433	 0.041575	 0.01342	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	55	 500	 0.004481	 0.041102	 0.01457	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 57	 0.00012	 0.01762	 0.0	 675.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	58	 57	 0.00012	 0.01762	 0.0	 675.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	57	 123	 0.001682	 0.024427	 0.42627	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	440	 57	 0.000601	 0.008726	 0.15227	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	59	 58	 0.00062	 0.003848	 0.0	 252.93	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	58	 253	 0.004532	 0.04352	 0.01405	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 58	 0.002019	 0.019385	 0.00626	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 58	 0.00202	 0.01939	 0.00626	 320.3	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	61	 60	 0.000529	 0.003518	 0.0	 0.32	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	60	 131	 0.001985	 0.018208	 0.00645	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	466	 60	 0.002011	 0.019314	 0.00623	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	63	 62	 0.0032	 0.16353	 0.0	 70.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	64	 62	 0.000661	 0.003274	 0.0	 45.58	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	287	 62	 0.005453	 0.052365	 0.0169	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	62	 457	 0.007267	 0.069786	 0.02253	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 65	 0.000808	 0.03088	 0.0	 405.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	80	 65	 0.00096	 0.013773	 0.24648	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	65	 297	 0.00092	 0.013192	 0.23607	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	67	 66	 0.000661	 0.003359	 0.0	 6.71	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	66	 308	 0.00718	 0.06895	 0.02226	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	69	 68	 0.000669	 0.003998	 0.0	 27.64	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68	 295	 0.004469	 0.040995	 0.01453	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	68	 314	 0.001805	 0.017334	 0.0056	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	71	 70	 0.00103	 0.04472	 0.0	 133.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	72	 70	 0.00292	 0.14481	 0.0	 60.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	73	 70	 0.012696	 0.27303	 0.0	 49.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	216	 70	 0.002596	 0.02381	 0.00844	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	70	 490	 0.002127	 0.019512	 0.00691	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	75	 74	 0.000584	 0.003339	 0.0	 8.81	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	74	 189	 0.005632	 0.054084	 0.01746	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 74	 0.004434	 0.04067	 0.01441	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	77	 76	 0.000695	 0.003313	 0.0	 12.16	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	452	 76	 0.002012	 0.019322	 0.00624	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	79	 78	 0.000622	 0.003279	 0.0	 0.52	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78	 328	 0.005432	 0.049829	 0.01766	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	78	 387	 0.002354	 0.022609	 0.0073	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	81	 80	 0.00065	 0.03481	 0.0	 529.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	82	 80	 0.00043	 0.03113	 0.0	 628.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	407	 80	 0.000818	 0.010825	 0.22813	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	149	 81	 0.002879	 0.02641	 0.00936	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	84	 83	 0.000638	 0.003655	 0.0	 105.41	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	83	 342	 0.004116	 0.03952	 0.01276	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	86	 85	 0.000652	 0.003901	 0.0	 30.04	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 85	 0.004412	 0.04047	 0.01434	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	88	 87	 0.000623	 0.003569	 0.0	 7.69	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87	 141	 0.001846	 0.017727	 0.00572	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	87	 143	 0.00382	 0.035043	 0.01242	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 87	 0.001836	 0.017627	 0.00569	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	90	 89	 0.000554	 0.003864	 0.0	 10.48	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 187	 0.002116	 0.020322	 0.00656	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	89	 457	 0.009012	 0.082666	 0.02929	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	92	 91	 0.000572	 0.003617	 0.0	 104.24	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	91	 133	 0.00504	 0.048401	 0.01562	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	94	 93	 0.000536	 0.003281	 0.0	 8.18	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	269	 93	 0.003921	 0.035965	 0.01275	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	336	 93	 0.005795	 0.053155	 0.01884	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	96	 95	 0.000563	 0.003253	 0.0	 56.18	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 170	 0.002111	 0.020268	 0.00654	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	95	 369	 0.004094	 0.039316	 0.01269	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	98	 97	 0.000569	 0.003986	 0.0	 66.43	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 97	 0.002992	 0.028734	 0.00928	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	358	 97	 0.002676	 0.024552	 0.0087	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	100	 99	 0.000644	 0.00362	 0.0	 22.69	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	101	 99	 0.000699	 0.003294	 0.0	 1.37	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	99	 465	 0.002689	 0.02582	 0.00834	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 99	 0.003318	 0.031864	 0.01029	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	103	 102	 0.000614	 0.003874	 0.0	 64.6	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	102	 308	 0.00565	 0.054254	 0.01751	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	419	 102	 0.003638	 0.034938	 0.01128	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	105	 104	 0.000673	 0.003751	 0.0	 144.23	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	104	 191	 0.005177	 0.047485	 0.01683	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	107	 106	 0.000575	 0.003206	 0.0	 24.46	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	106	 191	 0.004468	 0.042904	 0.01385	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 106	 0.003115	 0.029915	 0.00966	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	109	 108	 0.000658	 0.00301	 0.0	 62.91	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 472	 0.002033	 0.019521	 0.0063	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	108	 495	 0.003611	 0.034672	 0.01119	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	111	 110	 0.000527	 0.003708	 0.0	 87.02	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	274	 110	 0.003126	 0.030018	 0.00969	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	110	 316	 0.003439	 0.033025	 0.01066	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	113	 112	 0.000644	 0.003119	 0.0	 72.98	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	193	 112	 0.002867	 0.027534	 0.00889	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 236	 0.006329	 0.060777	 0.01962	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 283	 0.008619	 0.08276	 0.02672	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 112	 0.002007	 0.019267	 0.00622	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	112	 499	 0.005577	 0.051155	 0.01813	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	115	 114	 0.000506	 0.00336	 0.0	 6.74	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	116	 114	 0.000505	 0.003411	 0.0	 5.26	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	114	 191	 0.005557	 0.053364	 0.01723	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	114	 312	 0.006609	 0.063462	 0.02049	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	118	 117	 0.000634	 0.003851	 0.0	 12.8	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	117	 426	 0.003172	 0.029099	 0.01031	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	490	 117	 0.002999	 0.027508	 0.00975	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	120	 119	 0.000556	 0.003059	 0.0	 46.58	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	119	 129	 0.00235	 0.021554	 0.00764	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 119	 0.001494	 0.01435	 0.00463	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	122	 121	 0.000555	 0.003846	 0.0	 70.42	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 276	 0.002548	 0.024463	 0.0079	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	121	 287	 0.007088	 0.068058	 0.02197	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 123	 0.0002	 0.01438	 0.0	 488.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	125	 123	 0.00028	 0.04064	 0.0	 346.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	126	 123	 0.00015	 0.02189	 0.0	 352.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	127	 123	 0.00038	 0.04792	 0.0	 378.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	128	 123	 0.00016	 0.01585	 0.0	 391.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	165	 123	 0.000216	 0.003138	 0.05475	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 260	 0.00204	 0.018709	 0.00663	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	124	 369	 0.007693	 0.070568	 0.02501	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	130	 129	 0.000698	 0.003221	 0.0	 165.98	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	304	 129	 0.003063	 0.029412	 0.00949	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 129	 0.001878	 0.017231	 0.00611	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	132	 131	 0.000673	 0.003615	 0.0	 41.59	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	131	 333	 0.002227	 0.021386	 0.0069	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	134	 133	 0.000515	 0.003083	 0.0	 66.01	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 226	 0.00644	 0.059077	 0.02094	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	133	 369	 0.006155	 0.056462	 0.02001	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	473	 133	 0.004755	 0.045657	 0.01474	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	136	 135	 0.000549	 0.00366	 0.0	 45.59	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	135	 287	 0.007568	 0.069421	 0.0246	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	135	 457	 0.006865	 0.062973	 0.02232	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	138	 137	 0.000556	 0.003788	 0.0	 122.92	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 214	 0.00312	 0.029961	 0.00967	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 426	 0.002998	 0.028792	 0.00929	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	137	 426	 0.003	 0.02879	 0.00929	 320.3	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	140	 139	 0.0006	 0.003182	 0.0	 0.36	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	139	 376	 0.002676	 0.025697	 0.0083	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 139	 0.001468	 0.014094	 0.00455	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	142	 141	 0.000687	 0.003417	 0.0	 209.78	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	300	 141	 0.00267	 0.024495	 0.00868	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	144	 143	 0.00152	 0.0766	 0.0	 336.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	144	 143	 0.00152	 0.0766	 0.0	 336.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	145	 143	 0.00119	 0.0337	 0.0	 322.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	145	 143	 0.00119	 0.0337	 0.0	 322.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	143	 338	 0.002116	 0.019409	 0.00688	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	143	 401	 0.004057	 0.038957	 0.01258	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	143	 452	 0.007537	 0.07237	 0.02336	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	496	 143	 0.002039	 0.019581	 0.00632	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	147	 146	 0.001007	 0.05565	 0.0	 272.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	146	 162	 0.000285	 0.004083	 0.07307	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	146	 195	 0.000327	 0.004333	 0.09131	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	148	 147	 0.000593	 0.003935	 0.0	 102.39	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	475	 147	 0.003185	 0.030585	 0.00987	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	150	 149	 0.00068	 0.003693	 0.0	 2.36	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	293	 149	 0.004385	 0.042112	 0.01359	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	489	 149	 0.002444	 0.023466	 0.00758	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	152	 151	 0.000342	 0.0203	 0.0	 570.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	428	 151	 0.000454	 0.006011	 0.12668	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	153	 152	 0.000529	 0.003112	 0.0	 130.11	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	238	 152	 0.002155	 0.02069	 0.00668	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	155	 154	 0.000533	 0.003005	 0.0	 89.97	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	154	 429	 0.002119	 0.020352	 0.00657	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	154	 488	 0.008007	 0.07345	 0.02603	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	157	 156	 0.000597	 0.003579	 0.0	 164.26	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 156	 0.001861	 0.017075	 0.00605	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	159	 158	 0.000601	 0.003873	 0.0	 31.35	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 233	 0.006097	 0.055925	 0.01982	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	158	 291	 0.005133	 0.049293	 0.01591	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	161	 160	 0.000556	 0.003568	 0.0	 44.84	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 212	 0.002567	 0.02465	 0.00796	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	160	 399	 0.004015	 0.036828	 0.01305	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	163	 162	 0.000345	 0.01982	 0.0	 510.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	163	 162	 0.000366	 0.01982	 0.0	 510.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	162	 195	 0.000226	 0.003275	 0.05716	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	162	 220	 0.00139	 0.018388	 0.3875	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	162	 232	 0.000529	 0.007594	 0.13589	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	164	 163	 0.00065	 0.003987	 0.0	 174.51	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	200	 163	 0.003267	 0.029965	 0.01062	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 165	 0.000183	 0.00871	 0.0	 606.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	167	 165	 0.000463	 0.02157	 0.0	 411.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	168	 165	 0.00029	 0.03549	 0.0	 445.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	169	 165	 0.00035	 0.02558	 0.0	 543.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	165	 386	 0.000718	 0.010423	 0.18188	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 228	 0.004845	 0.044445	 0.01575	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	260	 166	 0.00199	 0.01825	 0.00647	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	166	 289	 0.002113	 0.020294	 0.00655	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	171	 170	 0.000513	 0.003774	 0.0	 20.92	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	170	 226	 0.004631	 0.042483	 0.01506	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	173	 172	 0.000675	 0.003134	 0.0	 4.69	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	174	 172	 0.000586	 0.003039	 0.0	 12.34	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	202	 172	 0.004073	 0.039112	 0.01263	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	172	 244	 0.003291	 0.031599	 0.0102	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	176	 175	 0.00039	 0.03857	 0.0	 273.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	175	 220	 0.001099	 0.01596	 0.27851	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	177	 176	 0.000557	 0.003649	 0.0	 12.91	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	178	 176	 0.000684	 0.003156	 0.0	 10.65	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	318	 176	 0.003427	 0.032909	 0.01062	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	180	 179	 0.000694	 0.003302	 0.0	 25.21	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 291	 0.005964	 0.05727	 0.01849	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 179	 0.005081	 0.046608	 0.01652	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	179	 374	 0.003774	 0.036236	 0.0117	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	182	 181	 0.000631	 0.003715	 0.0	 145.73	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	181	 487	 0.002751	 0.026421	 0.00853	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	184	 183	 0.000542	 0.003008	 0.0	 40.45	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 247	 0.001965	 0.018868	 0.00609	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	183	 274	 0.003673	 0.035265	 0.01138	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	186	 185	 0.000562	 0.003066	 0.0	 76.88	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 185	 0.003074	 0.028201	 0.00999	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	185	 467	 0.002016	 0.018496	 0.00655	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	188	 187	 0.00067	 0.003145	 0.0	 19.87	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	187	 454	 0.013848	 0.127035	 0.04502	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	190	 189	 0.00069	 0.00301	 0.0	 22.9	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	192	 191	 0.000684	 0.003764	 0.0	 27.24	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 205	 0.005326	 0.051141	 0.01651	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	191	 293	 0.005164	 0.049592	 0.01601	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	194	 193	 0.000696	 0.003802	 0.0	 49.31	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	196	 195	 0.00023	 0.01443	 0.0	 560.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	197	 195	 0.0006	 0.03102	 0.0	 597.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	198	 195	 0.000386	 0.02185	 0.0	 527.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	371	 195	 0.000451	 0.005966	 0.12573	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	199	 196	 0.000693	 0.003312	 0.0	 123.99	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	201	 200	 0.000686	 0.003174	 0.0	 14.82	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	203	 202	 0.000644	 0.003618	 0.0	 6.57	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	204	 202	 0.000553	 0.003889	 0.0	 72.65	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	380	 202	 0.00536	 0.05147	 0.01661	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	206	 205	 0.000554	 0.003028	 0.0	 4.37	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	207	 205	 0.000653	 0.0037	 0.0	 30.41	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	205	 312	 0.006767	 0.062072	 0.022	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	209	 208	 0.000514	 0.003601	 0.0	 141.36	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	322	 208	 0.00286	 0.027459	 0.00886	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	356	 208	 0.002554	 0.024525	 0.00792	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	211	 210	 0.000679	 0.003783	 0.0	 54.3	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	488	 210	 0.003712	 0.035641	 0.01151	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	213	 212	 0.000628	 0.003685	 0.0	 155.03	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	212	 399	 0.003344	 0.032113	 0.01037	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 212	 0.002879	 0.027648	 0.00893	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	215	 214	 0.000578	 0.003813	 0.0	 124.11	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	214	 403	 0.004217	 0.040493	 0.01307	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	217	 216	 0.0006	 0.003129	 0.0	 71.72	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	219	 218	 0.000581	 0.003657	 0.0	 0.6	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	218	 399	 0.004545	 0.043647	 0.01409	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 220	 0.000872	 0.02901	 0.0	 556.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	222	 220	 0.000485	 0.02225	 0.0	 228.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	223	 220	 0.000575	 0.03062	 0.0	 248.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	224	 220	 0.000543	 0.02404	 0.0	 588.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	224	 220	 0.00043	 0.02404	 0.0	 588.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	225	 220	 0.00018	 0.01242	 0.0	 628.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	225	 220	 0.00018	 0.01242	 0.0	 628.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	220	 471	 0.000978	 0.014205	 0.24789	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 447	 0.00397	 0.038119	 0.01231	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 478	 0.003036	 0.029155	 0.00941	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	221	 493	 0.003413	 0.032773	 0.01058	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	227	 226	 0.000667	 0.003347	 0.0	 8.92	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	229	 228	 0.00059	 0.003589	 0.0	 77.87	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 468	 0.004892	 0.046972	 0.01516	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	228	 474	 0.006513	 0.059749	 0.02117	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	231	 230	 0.00368	 0.18877	 0.0	 65.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	285	 230	 0.002749	 0.026397	 0.00852	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	233	 232	 0.00046	 0.0207	 0.0	 628.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	262	 232	 0.000253	 0.003627	 0.0649	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 371	 0.000494	 0.006532	 0.13765	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	232	 453	 0.000324	 0.004292	 0.09045	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	234	 233	 0.000551	 0.003415	 0.0	 95.68	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	233	 486	 0.002266	 0.021759	 0.00702	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	236	 235	 0.00024	 0.02788	 0.0	 507.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	235	 271	 0.000313	 0.004136	 0.08716	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	235	 407	 0.001237	 0.016366	 0.3449	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	237	 236	 0.000696	 0.003348	 0.0	 4.32	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	283	 236	 0.004516	 0.041425	 0.01468	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	239	 238	 0.000513	 0.003619	 0.0	 64.09	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	241	 240	 0.00054	 0.003983	 0.0	 27.17	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	240	 272	 0.011645	 0.10682	 0.03785	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	243	 242	 0.000606	 0.003702	 0.0	 130.7	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 287	 0.007052	 0.067713	 0.02186	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	242	 320	 0.003028	 0.029073	 0.00938	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	245	 244	 0.000598	 0.003153	 0.0	 15.81	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	244	 426	 0.0037	 0.033941	 0.01203	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	247	 246	 0.00123	 0.06785	 0.0	 271.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	248	 246	 0.001314	 0.05441	 0.0	 336.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	249	 246	 0.001385	 0.05427	 0.0	 333.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	250	 246	 0.00041	 0.02016	 0.0	 628.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	250	 246	 0.000393	 0.02016	 0.0	 628.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	246	 332	 0.000921	 0.01337	 0.23332	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	428	 246	 0.001101	 0.014563	 0.30689	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	246	 471	 0.001086	 0.014374	 0.30292	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	252	 251	 0.000661	 0.003863	 0.0	 171.55	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	251	 360	 0.004529	 0.041546	 0.01472	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 251	 0.004262	 0.04093	 0.01321	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	254	 253	 0.00422	 0.13453	 0.0	 134.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	255	 253	 0.00273	 0.10598	 0.0	 75.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	256	 253	 0.00659	 0.18871	 0.0	 65.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	257	 253	 0.00255	 0.08097	 0.0	 142.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	258	 253	 0.00935	 0.25929	 0.0	 52.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	259	 253	 0.000652	 0.003579	 0.0	 11.94	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 347	 0.00255	 0.024489	 0.00791	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	253	 417	 0.005333	 0.048916	 0.01733	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	261	 260	 0.000574	 0.003316	 0.0	 31.44	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 262	 0.000384	 0.01827	 0.0	 656.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	264	 262	 0.00052	 0.05005	 0.0	 255.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	265	 262	 0.00023	 0.03379	 0.0	 241.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	266	 263	 0.000571	 0.003406	 0.0	 107.16	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 276	 0.000864	 0.008296	 0.00268	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 326	 0.002523	 0.024229	 0.00782	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 476	 0.001806	 0.017343	 0.0056	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	263	 491	 0.003463	 0.033251	 0.01073	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	268	 267	 0.000502	 0.003575	 0.0	 206.87	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	312	 267	 0.004476	 0.042984	 0.01388	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	270	 269	 0.000574	 0.003977	 0.0	 10.95	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	475	 269	 0.003534	 0.033937	 0.01096	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	272	 271	 0.001006	 0.03765	 0.0	 484.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	273	 272	 0.000567	 0.003997	 0.0	 15.37	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	275	 274	 0.0012	 0.04081	 0.0	 225.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	277	 276	 0.000539	 0.003663	 0.0	 0.66	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	278	 276	 0.000529	 0.00385	 0.0	 8.45	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	276	 320	 0.00321	 0.030825	 0.00995	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	276	 485	 0.002629	 0.024118	 0.00855	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	280	 279	 0.000691	 0.003081	 0.0	 24.56	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	279	 340	 0.005965	 0.057279	 0.01849	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	279	 468	 0.003204	 0.030766	 0.00993	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	282	 281	 0.000539	 0.003617	 0.0	 203.73	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	310	 281	 0.002251	 0.021614	 0.00698	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 328	 0.004967	 0.04556	 0.01615	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	281	 384	 0.00383	 0.03678	 0.01187	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	284	 283	 0.000645	 0.003988	 0.0	 48.08	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	286	 285	 0.000667	 0.003266	 0.0	 13.41	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	285	 487	 0.003238	 0.031094	 0.01004	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	288	 287	 0.000507	 0.003818	 0.0	 89.94	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	287	 415	 0.004281	 0.039274	 0.01392	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	287	 476	 0.007441	 0.068262	 0.02419	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	290	 289	 0.000543	 0.003807	 0.0	 5.93	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	468	 289	 0.00577	 0.055406	 0.01789	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	292	 291	 0.000582	 0.003221	 0.0	 12.61	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	294	 293	 0.000645	 0.00329	 0.0	 35.71	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	296	 295	 0.000531	 0.003433	 0.0	 10.75	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	314	 295	 0.003193	 0.030657	 0.0099	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	295	 447	 0.00342	 0.031369	 0.01112	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	477	 295	 0.003486	 0.03347	 0.0108	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	298	 297	 0.000588	 0.03135	 0.0	 348.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	425	 297	 0.000275	 0.003997	 0.06976	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	297	 440	 0.000652	 0.009346	 0.16726	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	299	 298	 0.00054	 0.003634	 0.0	 20.05	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	298	 426	 0.003241	 0.031118	 0.01005	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	301	 300	 0.00245	 0.08126	 0.0	 67.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	302	 300	 0.00367	 0.07834	 0.0	 75.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	303	 300	 0.000646	 0.003997	 0.0	 139.23	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	405	 300	 0.003374	 0.032399	 0.01046	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	300	 478	 0.008364	 0.080315	 0.02593	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	305	 304	 0.02066	 0.53593	 0.0	 28.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	306	 304	 0.00522	 0.24992	 0.0	 63.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	307	 304	 0.000547	 0.003467	 0.0	 122.19	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	309	 308	 0.000658	 0.003995	 0.0	 13.62	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	308	 500	 0.006944	 0.066685	 0.02153	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	311	 310	 0.000617	 0.003587	 0.0	 60.45	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	358	 310	 0.002931	 0.026886	 0.00953	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	313	 312	 0.000642	 0.003976	 0.0	 17.95	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	399	 312	 0.004822	 0.046299	 0.01495	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	315	 314	 0.000536	 0.003143	 0.0	 0.67	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	317	 316	 0.000671	 0.003045	 0.0	 5.45	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	319	 318	 0.00159	 0.07586	 0.0	 120.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	318	 336	 0.005467	 0.050154	 0.01777	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 318	 0.001301	 0.012497	 0.00403	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	321	 320	 0.000626	 0.003619	 0.0	 269.4	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	323	 322	 0.000658	 0.003109	 0.0	 75.55	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	324	 322	 0.001572	 0.014419	 0.00511	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	325	 324	 0.000537	 0.003712	 0.0	 146.36	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	327	 326	 0.000571	 0.003193	 0.0	 159.77	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	491	 326	 0.002389	 0.022943	 0.00741	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	329	 328	 0.000554	 0.003034	 0.0	 40.66	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	331	 330	 0.00057	 0.003882	 0.0	 77.39	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	333	 330	 0.001518	 0.014574	 0.0047	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	449	 330	 0.002073	 0.019909	 0.00643	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	333	 332	 0.00074	 0.02644	 0.0	 508.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	332	 471	 0.000258	 0.003415	 0.07196	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	334	 333	 0.000662	 0.003196	 0.0	 0.85	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	335	 333	 0.000627	 0.003552	 0.0	 1.26	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	337	 336	 0.000563	 0.003904	 0.0	 9.71	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	378	 336	 0.005079	 0.048769	 0.01574	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	492	 336	 0.006321	 0.060695	 0.01959	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	339	 338	 0.000558	 0.003629	 0.0	 98.2	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	338	 459	 0.001952	 0.017902	 0.00634	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	341	 340	 0.000618	 0.003847	 0.0	 43.31	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	460	 340	 0.003698	 0.035512	 0.01146	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	343	 342	 0.000576	 0.003628	 0.0	 3.7	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	344	 342	 0.000571	 0.003876	 0.0	 3.28	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	346	 345	 0.000557	 0.003186	 0.0	 72.41	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	345	 415	 0.007099	 0.065124	 0.02308	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	348	 347	 0.000579	 0.003119	 0.0	 138.46	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	347	 417	 0.005551	 0.050922	 0.01805	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	350	 349	 0.0027	 0.0716	 0.0	 183.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	351	 349	 0.00389	 0.07925	 0.0	 142.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	352	 349	 0.003046	 0.07211	 0.0	 150.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	353	 349	 0.0027	 0.0722	 0.0	 206.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	349	 403	 0.002617	 0.025132	 0.00811	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	355	 354	 0.000688	 0.00376	 0.0	 28.27	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	421	 354	 0.004766	 0.04577	 0.01477	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	479	 354	 0.004376	 0.042023	 0.01357	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	357	 356	 0.000552	 0.003425	 0.0	 84.77	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	356	 382	 0.002848	 0.027352	 0.00883	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	359	 358	 0.00067	 0.003506	 0.0	 25.0	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	361	 360	 0.01388	 0.33724	 0.0	 52.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	362	 360	 0.00354	 0.11798	 0.0	 162.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	363	 360	 0.00224	 0.11593	 0.0	 75.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	364	 360	 0.000513	 0.003558	 0.0	 40.25	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	360	 417	 0.008124	 0.078008	 0.02518	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	366	 365	 0.000541	 0.003915	 0.0	 101.52	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 374	 0.002836	 0.027231	 0.00879	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	365	 454	 0.002302	 0.022105	 0.00714	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	368	 367	 0.000517	 0.003214	 0.0	 17.62	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 461	 0.006326	 0.058028	 0.02056	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	367	 468	 0.008321	 0.076331	 0.02705	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	370	 369	 0.000569	 0.003063	 0.0	 62.18	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	372	 371	 0.00025	 0.03602	 0.0	 508.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	373	 372	 0.000581	 0.003181	 0.0	 48.53	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	375	 374	 0.000501	 0.003007	 0.0	 43.22	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	377	 376	 0.000502	 0.003355	 0.0	 162.43	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 429	 0.002745	 0.026362	 0.00851	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 460	 0.002246	 0.021565	 0.00696	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 469	 0.004909	 0.045034	 0.01596	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	376	 495	 0.003326	 0.031936	 0.01031	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	379	 378	 0.000587	 0.003819	 0.0	 20.35	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	381	 380	 0.000529	 0.00359	 0.0	 14.39	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	493	 380	 0.003409	 0.032738	 0.01057	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	383	 382	 0.000541	 0.003573	 0.0	 44.49	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	385	 384	 0.000568	 0.003148	 0.0	 48.14	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 384	 0.002936	 0.028195	 0.0091	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	387	 386	 0.00016	 0.01653	 0.0	 658.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	387	 386	 0.00016	 0.01653	 0.0	 658.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	388	 386	 0.00036	 0.04243	 0.0	 255.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	389	 386	 0.00043	 0.03576	 0.0	 374.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	390	 386	 0.00021	 0.02728	 0.0	 389.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	391	 386	 0.00023	 0.02451	 0.0	 399.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	392	 386	 0.00029	 0.03299	 0.0	 297.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	393	 386	 0.00024	 0.03349	 0.0	 283.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	394	 386	 0.00039	 0.022	 0.0	 318.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	395	 386	 0.00104	 0.05624	 0.0	 312.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	396	 386	 0.00015	 0.02168	 0.0	 313.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	440	 386	 0.000855	 0.012265	 0.21949	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	397	 387	 0.000514	 0.0033	 0.0	 66.7	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	398	 387	 0.000692	 0.003106	 0.0	 24.41	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	387	 467	 0.003151	 0.028903	 0.01024	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	387	 470	 0.002138	 0.019612	 0.00695	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	400	 399	 0.000694	 0.003966	 0.0	 31.68	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 399	 0.001618	 0.015538	 0.00502	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	402	 401	 0.000511	 0.003712	 0.0	 123.69	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	404	 403	 0.000616	 0.003466	 0.0	 26.17	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	406	 405	 0.000583	 0.003551	 0.0	 8.23	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	492	 405	 0.004321	 0.041496	 0.0134	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	408	 407	 0.00036	 0.01366	 0.0	 595.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	409	 407	 0.00054	 0.0611	 0.0	 326.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	410	 407	 0.00027	 0.04197	 0.0	 445.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	411	 407	 0.00016	 0.02349	 0.0	 441.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	412	 407	 0.0002	 0.02693	 0.0	 431.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	413	 407	 0.00056	 0.04036	 0.0	 436.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	414	 407	 0.000999	 0.04423	 0.0	 342.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	416	 415	 0.00053	 0.003834	 0.0	 8.66	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	418	 417	 0.000648	 0.003517	 0.0	 109.42	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 468	 0.003561	 0.032669	 0.01158	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 469	 0.004887	 0.044829	 0.01589	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	417	 474	 0.003457	 0.033193	 0.01072	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	420	 419	 0.000565	 0.003753	 0.0	 8.45	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	422	 421	 0.000628	 0.003106	 0.0	 65.44	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	424	 423	 0.000683	 0.003864	 0.0	 273.23	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	423	 496	 0.003743	 0.035945	 0.0116	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	426	 425	 0.00087	 0.03219	 0.0	 554.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	427	 426	 0.000676	 0.003027	 0.0	 18.8	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	429	 428	 0.00013	 0.00868	 0.0	 646.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	430	 428	 0.00118	 0.06355	 0.0	 207.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	431	 428	 0.00037	 0.03646	 0.0	 225.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	432	 428	 0.00023	 0.03175	 0.0	 204.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	433	 428	 0.0008	 0.09098	 0.0	 218.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	434	 428	 0.0003	 0.02264	 0.0	 231.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	435	 428	 0.00029	 0.02826	 0.0	 458.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	436	 428	 0.00022	 0.01431	 0.0	 457.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	437	 428	 0.00014	 0.01844	 0.0	 471.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	438	 428	 0.000524	 0.02322	 0.0	 492.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	439	 428	 0.00012	 0.01452	 0.0	 474.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	429	 466	 0.001853	 0.016994	 0.00602	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	441	 440	 0.00058	 0.02873	 0.0	 649.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	442	 440	 0.0005	 0.04469	 0.0	 267.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	443	 440	 0.00018	 0.02669	 0.0	 385.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	444	 440	 0.00108	 0.08953	 0.0	 202.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	446	 445	 0.00068	 0.003579	 0.0	 130.2	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	445	 461	 0.00331	 0.031785	 0.01026	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	448	 447	 0.000578	 0.003842	 0.0	 76.12	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	450	 449	 0.000521	 0.003328	 0.0	 1.48	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	451	 449	 0.000525	 0.003193	 0.0	 3.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	495	 449	 0.001762	 0.016167	 0.00573	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	454	 453	 0.0002	 0.03057	 0.0	 634.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	455	 453	 0.00026	 0.01616	 0.0	 551.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	456	 453	 0.00015	 0.01668	 0.0	 651.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	485	 454	 0.00205	 0.019688	 0.00636	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	458	 457	 0.00201	 0.07218	 0.0	 207.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	459	 496	 0.002071	 0.019002	 0.00673	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	463	 462	 0.00181	 0.09575	 0.0	 80.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	462	 465	 0.003271	 0.031414	 0.01014	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	462	 477	 0.005013	 0.048141	 0.01554	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	465	 464	 0.00036	 0.02723	 0.0	 384.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	471	 464	 0.000427	 0.006128	 0.10966	 1493.89	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	470	 467	 0.001632	 0.014967	 0.0053	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	472	 471	 0.00016	 0.01869	 0.0	 501.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	476	 486	 0.002501	 0.024018	 0.00775	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	480	 479	 0.00242	 0.06304	 0.0	 221.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	481	 479	 0.00104	 0.05504	 0.0	 160.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	482	 479	 0.00123	 0.03182	 0.0	 187.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	483	 479	 0.00343	 0.10067	 0.0	 187.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	484	 479	 0.00146	 0.05489	 0.0	 140.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	485	 499	 0.003774	 0.034616	 0.01227	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	500	 489	 0.004696	 0.043073	 0.01526	 320.29	 0.0	 0.0	 0.0	 0.0	 1	 -30.0	 30.0;
	494	 493	 0.00119	 0.0643	 0.0	 75.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	497	 496	 0.00147	 0.0647	 0.0	 204.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
	498	 496	 0.004006	 0.11755	 0.0	 150.0	 0.0	 0.0	 1.0	 0.0	 1	 -30.0	 30.0;
];

% INFO    : === Translation Options ===
% INFO    : Phase Angle Bound:           30.0 (deg.)
% INFO    : Setting Flat Start
% INFO    : 
% INFO    : === Base KV Replacement Notes ===
% INFO    : 
% INFO    : === Transformer Setting Replacement Notes ===
% INFO    : 
% INFO    : === Voltage Setpoint Replacement Notes ===
% INFO    : Bus 1	: V=1.0121594, theta=-10.768348 -> V=1.0, theta=0.0
% INFO    : Bus 2	: V=1.0115797, theta=-10.840156 -> V=1.0, theta=0.0
% INFO    : Bus 3	: V=1.0062303, theta=-12.071857 -> V=1.0, theta=0.0
% INFO    : Bus 4	: V=1.0040662, theta=-12.322717 -> V=1.0, theta=0.0
% INFO    : Bus 5	: V=1.0146988, theta=-1.264301 -> V=1.0, theta=0.0
% INFO    : Bus 6	: V=1.0146511, theta=-1.270407 -> V=1.0, theta=0.0
% INFO    : Bus 7	: V=1.0338633, theta=-6.93107 -> V=1.0, theta=0.0
% INFO    : Bus 8	: V=1.0269631, theta=-8.712158 -> V=1.0, theta=0.0
% INFO    : Bus 9	: V=1.04, theta=-4.132565 -> V=1.0, theta=0.0
% INFO    : Bus 10	: V=1.0167054, theta=-13.818521 -> V=1.0, theta=0.0
% INFO    : Bus 11	: V=1.0166687, theta=-13.822668 -> V=1.0, theta=0.0
% INFO    : Bus 12	: V=0.9918009, theta=-14.544799 -> V=1.0, theta=0.0
% INFO    : Bus 13	: V=0.9912534, theta=-14.609077 -> V=1.0, theta=0.0
% INFO    : Bus 14	: V=1.0300871, theta=-3.407512 -> V=1.0, theta=0.0
% INFO    : Bus 15	: V=1.0213804, theta=-6.028249 -> V=1.0, theta=0.0
% INFO    : Bus 16	: V=1.04, theta=-0.563895 -> V=1.0, theta=0.0
% INFO    : Bus 17	: V=1.04, theta=0.0 -> V=1.0, theta=0.0
% INFO    : Bus 18	: V=1.04, theta=0.891476 -> V=1.0, theta=0.0
% INFO    : Bus 19	: V=1.0183477, theta=-14.29614 -> V=1.0, theta=0.0
% INFO    : Bus 20	: V=1.0182774, theta=-14.305529 -> V=1.0, theta=0.0
% INFO    : Bus 21	: V=1.00952, theta=-12.34143 -> V=1.0, theta=0.0
% INFO    : Bus 22	: V=1.0073941, theta=-12.594211 -> V=1.0, theta=0.0
% INFO    : Bus 23	: V=1.027297, theta=-7.930431 -> V=1.0, theta=0.0
% INFO    : Bus 24	: V=1.0123427, theta=-10.816709 -> V=1.0, theta=0.0
% INFO    : Bus 25	: V=1.0123071, theta=-10.821133 -> V=1.0, theta=0.0
% INFO    : Bus 26	: V=1.0120091, theta=-10.860073 -> V=1.0, theta=0.0
% INFO    : Bus 27	: V=1.0131877, theta=-16.550327 -> V=1.0, theta=0.0
% INFO    : Bus 28	: V=1.0121009, theta=-16.683236 -> V=1.0, theta=0.0
% INFO    : Bus 29	: V=1.0094314, theta=-14.585453 -> V=1.0, theta=0.0
% INFO    : Bus 30	: V=1.0079428, theta=-14.761896 -> V=1.0, theta=0.0
% INFO    : Bus 31	: V=1.0324536, theta=-17.056434 -> V=1.0, theta=0.0
% INFO    : Bus 32	: V=1.0323079, theta=-17.07356 -> V=1.0, theta=0.0
% INFO    : Bus 33	: V=1.0062025, theta=-15.223413 -> V=1.0, theta=0.0
% INFO    : Bus 34	: V=1.0058294, theta=-15.267528 -> V=1.0, theta=0.0
% INFO    : Bus 35	: V=1.0176565, theta=-15.888312 -> V=1.0, theta=0.0
% INFO    : Bus 36	: V=1.0170629, theta=-15.957294 -> V=1.0, theta=0.0
% INFO    : Bus 37	: V=1.019326, theta=-0.912831 -> V=1.0, theta=0.0
% INFO    : Bus 38	: V=1.019324, theta=-0.913092 -> V=1.0, theta=0.0
% INFO    : Bus 39	: V=1.029536, theta=-7.806151 -> V=1.0, theta=0.0
% INFO    : Bus 40	: V=1.0230801, theta=-9.013592 -> V=1.0, theta=0.0
% INFO    : Bus 41	: V=1.0221263, theta=-9.13288 -> V=1.0, theta=0.0
% INFO    : Bus 42	: V=1.0241182, theta=-13.629013 -> V=1.0, theta=0.0
% INFO    : Bus 43	: V=1.0240584, theta=-13.636262 -> V=1.0, theta=0.0
% INFO    : Bus 44	: V=1.0183376, theta=-9.780178 -> V=1.0, theta=0.0
% INFO    : Bus 45	: V=1.0183043, theta=-9.784337 -> V=1.0, theta=0.0
% INFO    : Bus 46	: V=1.0041544, theta=-13.176609 -> V=1.0, theta=0.0
% INFO    : Bus 47	: V=1.0034945, theta=-13.257904 -> V=1.0, theta=0.0
% INFO    : Bus 48	: V=1.0009431, theta=-17.76377 -> V=1.0, theta=0.0
% INFO    : Bus 49	: V=1.002792, theta=-17.561683 -> V=1.0, theta=0.0
% INFO    : Bus 50	: V=1.0030954, theta=-17.52604 -> V=1.0, theta=0.0
% INFO    : Bus 51	: V=1.0009373, theta=-17.764478 -> V=1.0, theta=0.0
% INFO    : Bus 52	: V=1.0005895, theta=-17.806277 -> V=1.0, theta=0.0
% INFO    : Bus 53	: V=1.0165292, theta=-13.251455 -> V=1.0, theta=0.0
% INFO    : Bus 54	: V=1.0160159, theta=-13.307067 -> V=1.0, theta=0.0
% INFO    : Bus 55	: V=1.0191294, theta=-13.193049 -> V=1.0, theta=0.0
% INFO    : Bus 56	: V=1.0190957, theta=-13.19695 -> V=1.0, theta=0.0
% INFO    : Bus 57	: V=1.0102301, theta=-9.631096 -> V=1.0, theta=0.0
% INFO    : Bus 58	: V=1.0019704, theta=-12.45089 -> V=1.0, theta=0.0
% INFO    : Bus 59	: V=0.9996353, theta=-12.747819 -> V=1.0, theta=0.0
% INFO    : Bus 60	: V=1.0195458, theta=-9.574278 -> V=1.0, theta=0.0
% INFO    : Bus 61	: V=1.0195429, theta=-9.574657 -> V=1.0, theta=0.0
% INFO    : Bus 62	: V=1.0098039, theta=-11.911949 -> V=1.0, theta=0.0
% INFO    : Bus 63	: V=1.0098039, theta=-11.911949 -> V=1.0, theta=0.0
% INFO    : Bus 64	: V=1.0092747, theta=-11.972508 -> V=1.0, theta=0.0
% INFO    : Bus 65	: V=1.0253984, theta=-10.657074 -> V=1.0, theta=0.0
% INFO    : Bus 66	: V=1.0213047, theta=-12.355135 -> V=1.0, theta=0.0
% INFO    : Bus 67	: V=1.021235, theta=-12.363122 -> V=1.0, theta=0.0
% INFO    : Bus 68	: V=1.0095454, theta=-13.55949 -> V=1.0, theta=0.0
% INFO    : Bus 69	: V=1.0092536, theta=-13.595925 -> V=1.0, theta=0.0
% INFO    : Bus 70	: V=0.9952003, theta=-14.853739 -> V=1.0, theta=0.0
% INFO    : Bus 71	: V=0.9959298, theta=-14.751248 -> V=1.0, theta=0.0
% INFO    : Bus 72	: V=0.9963709, theta=-14.687687 -> V=1.0, theta=0.0
% INFO    : Bus 73	: V=0.996844, theta=-14.636919 -> V=1.0, theta=0.0
% INFO    : Bus 74	: V=1.0250334, theta=-16.893698 -> V=1.0, theta=0.0
% INFO    : Bus 75	: V=1.0249571, theta=-16.9029 -> V=1.0, theta=0.0
% INFO    : Bus 76	: V=1.017795, theta=-0.028885 -> V=1.0, theta=0.0
% INFO    : Bus 77	: V=1.0176872, theta=-0.04091 -> V=1.0, theta=0.0
% INFO    : Bus 78	: V=1.0126457, theta=-8.449181 -> V=1.0, theta=0.0
% INFO    : Bus 79	: V=1.0126401, theta=-8.449844 -> V=1.0, theta=0.0
% INFO    : Bus 80	: V=1.0318766, theta=-10.20359 -> V=1.0, theta=0.0
% INFO    : Bus 81	: V=1.0261976, theta=-12.787872 -> V=1.0, theta=0.0
% INFO    : Bus 82	: V=1.04, theta=-4.187069 -> V=1.0, theta=0.0
% INFO    : Bus 83	: V=1.0042842, theta=-15.618602 -> V=1.0, theta=0.0
% INFO    : Bus 84	: V=1.0032952, theta=-15.7403 -> V=1.0, theta=0.0
% INFO    : Bus 85	: V=1.0261471, theta=-15.871977 -> V=1.0, theta=0.0
% INFO    : Bus 86	: V=1.0258566, theta=-15.907664 -> V=1.0, theta=0.0
% INFO    : Bus 87	: V=1.0010163, theta=0.765842 -> V=1.0, theta=0.0
% INFO    : Bus 88	: V=1.0009336, theta=0.755621 -> V=1.0, theta=0.0
% INFO    : Bus 89	: V=1.0178037, theta=-11.12825 -> V=1.0, theta=0.0
% INFO    : Bus 90	: V=1.0177118, theta=-11.14038 -> V=1.0, theta=0.0
% INFO    : Bus 91	: V=1.0117544, theta=-7.578928 -> V=1.0, theta=0.0
% INFO    : Bus 92	: V=1.0107636, theta=-7.705162 -> V=1.0, theta=0.0
% INFO    : Bus 93	: V=1.0153922, theta=-6.433699 -> V=1.0, theta=0.0
% INFO    : Bus 94	: V=1.0153197, theta=-6.442794 -> V=1.0, theta=0.0
% INFO    : Bus 95	: V=1.0121742, theta=-7.546726 -> V=1.0, theta=0.0
% INFO    : Bus 96	: V=1.011693, theta=-7.605762 -> V=1.0, theta=0.0
% INFO    : Bus 97	: V=1.0046514, theta=-18.177695 -> V=1.0, theta=0.0
% INFO    : Bus 98	: V=1.0040476, theta=-18.258479 -> V=1.0, theta=0.0
% INFO    : Bus 99	: V=1.0221931, theta=-9.163343 -> V=1.0, theta=0.0
% INFO    : Bus 100	: V=1.02198, theta=-9.188916 -> V=1.0, theta=0.0
% INFO    : Bus 101	: V=1.0221794, theta=-9.164861 -> V=1.0, theta=0.0
% INFO    : Bus 102	: V=1.0029364, theta=-16.615939 -> V=1.0, theta=0.0
% INFO    : Bus 103	: V=1.0022978, theta=-16.697995 -> V=1.0, theta=0.0
% INFO    : Bus 104	: V=1.0184026, theta=-17.457678 -> V=1.0, theta=0.0
% INFO    : Bus 105	: V=1.0170774, theta=-17.616391 -> V=1.0, theta=0.0
% INFO    : Bus 106	: V=1.0202726, theta=-14.781528 -> V=1.0, theta=0.0
% INFO    : Bus 107	: V=1.0200482, theta=-14.80843 -> V=1.0, theta=0.0
% INFO    : Bus 108	: V=1.0151317, theta=-10.097752 -> V=1.0, theta=0.0
% INFO    : Bus 109	: V=1.0144458, theta=-10.172782 -> V=1.0, theta=0.0
% INFO    : Bus 110	: V=1.0272383, theta=-4.906973 -> V=1.0, theta=0.0
% INFO    : Bus 111	: V=1.0263161, theta=-5.027748 -> V=1.0, theta=0.0
% INFO    : Bus 112	: V=1.0140803, theta=-13.767323 -> V=1.0, theta=0.0
% INFO    : Bus 113	: V=1.0134095, theta=-13.842899 -> V=1.0, theta=0.0
% INFO    : Bus 114	: V=1.0191486, theta=-16.294584 -> V=1.0, theta=0.0
% INFO    : Bus 115	: V=1.019079, theta=-16.30359 -> V=1.0, theta=0.0
% INFO    : Bus 116	: V=1.0191056, theta=-16.300185 -> V=1.0, theta=0.0
% INFO    : Bus 117	: V=1.0045114, theta=-13.926792 -> V=1.0, theta=0.0
% INFO    : Bus 118	: V=1.0043653, theta=-13.94526 -> V=1.0, theta=0.0
% INFO    : Bus 119	: V=0.9870946, theta=-15.396824 -> V=1.0, theta=0.0
% INFO    : Bus 120	: V=0.9866541, theta=-15.451021 -> V=1.0, theta=0.0
% INFO    : Bus 121	: V=1.0129046, theta=-13.971263 -> V=1.0, theta=0.0
% INFO    : Bus 122	: V=1.0120693, theta=-14.081572 -> V=1.0, theta=0.0
% INFO    : Bus 123	: V=1.0300843, theta=-3.755483 -> V=1.0, theta=0.0
% INFO    : Bus 124	: V=1.0276461, theta=-4.458626 -> V=1.0, theta=0.0
% INFO    : Bus 125	: V=1.0300843, theta=-3.755483 -> V=1.0, theta=0.0
% INFO    : Bus 126	: V=1.0300843, theta=-3.755483 -> V=1.0, theta=0.0
% INFO    : Bus 127	: V=1.04, theta=0.394755 -> V=1.0, theta=0.0
% INFO    : Bus 128	: V=1.0395249, theta=-2.386765 -> V=1.0, theta=0.0
% INFO    : Bus 129	: V=0.9842018, theta=-15.914608 -> V=1.0, theta=0.0
% INFO    : Bus 130	: V=0.9825607, theta=-16.100251 -> V=1.0, theta=0.0
% INFO    : Bus 131	: V=1.0202588, theta=-9.44535 -> V=1.0, theta=0.0
% INFO    : Bus 132	: V=1.0198539, theta=-9.49303 -> V=1.0, theta=0.0
% INFO    : Bus 133	: V=1.0129048, theta=-7.505509 -> V=1.0, theta=0.0
% INFO    : Bus 134	: V=1.0123408, theta=-7.575691 -> V=1.0, theta=0.0
% INFO    : Bus 135	: V=1.0152678, theta=-11.328869 -> V=1.0, theta=0.0
% INFO    : Bus 136	: V=1.0148653, theta=-11.381154 -> V=1.0, theta=0.0
% INFO    : Bus 137	: V=1.0068193, theta=-14.045005 -> V=1.0, theta=0.0
% INFO    : Bus 138	: V=1.0055899, theta=-14.207124 -> V=1.0, theta=0.0
% INFO    : Bus 139	: V=1.015832, theta=-10.108334 -> V=1.0, theta=0.0
% INFO    : Bus 140	: V=1.0158284, theta=-10.108762 -> V=1.0, theta=0.0
% INFO    : Bus 141	: V=1.0005818, theta=-2.499145 -> V=1.0, theta=0.0
% INFO    : Bus 142	: V=0.997985, theta=-2.798498 -> V=1.0, theta=0.0
% INFO    : Bus 143	: V=1.0187768, theta=6.50236 -> V=1.0, theta=0.0
% INFO    : Bus 144	: V=1.04, theta=19.035856 -> V=1.0, theta=0.0
% INFO    : Bus 145	: V=1.04, theta=9.200971 -> V=1.0, theta=0.0
% INFO    : Bus 146	: V=1.0287905, theta=-7.881098 -> V=1.0, theta=0.0
% INFO    : Bus 147	: V=1.0171175, theta=-8.557608 -> V=1.0, theta=0.0
% INFO    : Bus 148	: V=1.0161874, theta=-8.677833 -> V=1.0, theta=0.0
% INFO    : Bus 149	: V=1.0220666, theta=-13.723278 -> V=1.0, theta=0.0
% INFO    : Bus 150	: V=1.0220421, theta=-13.726173 -> V=1.0, theta=0.0
% INFO    : Bus 151	: V=1.0281863, theta=-8.035489 -> V=1.0, theta=0.0
% INFO    : Bus 152	: V=1.0273611, theta=-10.434389 -> V=1.0, theta=0.0
% INFO    : Bus 153	: V=1.0261234, theta=-10.584818 -> V=1.0, theta=0.0
% INFO    : Bus 154	: V=1.0102266, theta=-10.979578 -> V=1.0, theta=0.0
% INFO    : Bus 155	: V=1.0093414, theta=-11.087115 -> V=1.0, theta=0.0
% INFO    : Bus 156	: V=0.9894442, theta=-14.616821 -> V=1.0, theta=0.0
% INFO    : Bus 157	: V=0.9877808, theta=-14.828219 -> V=1.0, theta=0.0
% INFO    : Bus 158	: V=1.0108477, theta=-13.532131 -> V=1.0, theta=0.0
% INFO    : Bus 159	: V=1.0104779, theta=-13.579723 -> V=1.0, theta=0.0
% INFO    : Bus 160	: V=1.019849, theta=-15.042923 -> V=1.0, theta=0.0
% INFO    : Bus 161	: V=1.019465, theta=-15.091831 -> V=1.0, theta=0.0
% INFO    : Bus 162	: V=1.0290799, theta=-7.842996 -> V=1.0, theta=0.0
% INFO    : Bus 163	: V=1.0251989, theta=-8.622978 -> V=1.0, theta=0.0
% INFO    : Bus 164	: V=1.0235494, theta=-8.827381 -> V=1.0, theta=0.0
% INFO    : Bus 165	: V=1.0303877, theta=-3.402552 -> V=1.0, theta=0.0
% INFO    : Bus 166	: V=1.024584, theta=-4.970343 -> V=1.0, theta=0.0
% INFO    : Bus 167	: V=1.04, theta=-1.181749 -> V=1.0, theta=0.0
% INFO    : Bus 168	: V=1.04, theta=0.266644 -> V=1.0, theta=0.0
% INFO    : Bus 169	: V=1.04, theta=1.888281 -> V=1.0, theta=0.0
% INFO    : Bus 170	: V=1.0116907, theta=-7.684683 -> V=1.0, theta=0.0
% INFO    : Bus 171	: V=1.0115047, theta=-7.709885 -> V=1.0, theta=0.0
% INFO    : Bus 172	: V=1.0049781, theta=-12.79909 -> V=1.0, theta=0.0
% INFO    : Bus 173	: V=1.004931, theta=-12.804343 -> V=1.0, theta=0.0
% INFO    : Bus 174	: V=1.0048766, theta=-12.811037 -> V=1.0, theta=0.0
% INFO    : Bus 175	: V=1.0339354, theta=-3.550348 -> V=1.0, theta=0.0
% INFO    : Bus 176	: V=1.0230476, theta=-2.722604 -> V=1.0, theta=0.0
% INFO    : Bus 177	: V=1.0229161, theta=-2.739433 -> V=1.0, theta=0.0
% INFO    : Bus 178	: V=1.0229459, theta=-2.733694 -> V=1.0, theta=0.0
% INFO    : Bus 179	: V=1.0042483, theta=-14.756946 -> V=1.0, theta=0.0
% INFO    : Bus 180	: V=1.0040265, theta=-14.781985 -> V=1.0, theta=0.0
% INFO    : Bus 181	: V=1.0112149, theta=-17.97497 -> V=1.0, theta=0.0
% INFO    : Bus 182	: V=1.009884, theta=-18.139381 -> V=1.0, theta=0.0
% INFO    : Bus 183	: V=1.0248361, theta=-6.66188 -> V=1.0, theta=0.0
% INFO    : Bus 184	: V=1.0244398, theta=-6.709043 -> V=1.0, theta=0.0
% INFO    : Bus 185	: V=1.009542, theta=-9.259349 -> V=1.0, theta=0.0
% INFO    : Bus 186	: V=1.0089212, theta=-9.333731 -> V=1.0, theta=0.0
% INFO    : Bus 187	: V=1.0171045, theta=-11.513978 -> V=1.0, theta=0.0
% INFO    : Bus 188	: V=1.0169406, theta=-11.532133 -> V=1.0, theta=0.0
% INFO    : Bus 189	: V=1.0278199, theta=-17.179459 -> V=1.0, theta=0.0
% INFO    : Bus 190	: V=1.0276155, theta=-17.201031 -> V=1.0, theta=0.0
% INFO    : Bus 191	: V=1.0196265, theta=-15.768651 -> V=1.0, theta=0.0
% INFO    : Bus 192	: V=1.0193542, theta=-15.801108 -> V=1.0, theta=0.0
% INFO    : Bus 193	: V=1.0153022, theta=-14.252592 -> V=1.0, theta=0.0
% INFO    : Bus 194	: V=1.0148183, theta=-14.310301 -> V=1.0, theta=0.0
% INFO    : Bus 195	: V=1.029082, theta=-7.870717 -> V=1.0, theta=0.0
% INFO    : Bus 196	: V=1.0196956, theta=-10.12389 -> V=1.0, theta=0.0
% INFO    : Bus 197	: V=1.04, theta=-3.003092 -> V=1.0, theta=0.0
% INFO    : Bus 198	: V=1.04, theta=-5.456007 -> V=1.0, theta=0.0
% INFO    : Bus 199	: V=1.0183547, theta=-10.272974 -> V=1.0, theta=0.0
% INFO    : Bus 200	: V=1.0206965, theta=-9.381187 -> V=1.0, theta=0.0
% INFO    : Bus 201	: V=1.020563, theta=-9.395812 -> V=1.0, theta=0.0
% INFO    : Bus 202	: V=1.0022863, theta=-12.303216 -> V=1.0, theta=0.0
% INFO    : Bus 203	: V=1.002211, theta=-12.312433 -> V=1.0, theta=0.0
% INFO    : Bus 204	: V=1.0015598, theta=-12.400743 -> V=1.0, theta=0.0
% INFO    : Bus 205	: V=1.0217148, theta=-16.68876 -> V=1.0, theta=0.0
% INFO    : Bus 206	: V=1.0216747, theta=-16.693517 -> V=1.0, theta=0.0
% INFO    : Bus 207	: V=1.0213521, theta=-16.732462 -> V=1.0, theta=0.0
% INFO    : Bus 208	: V=1.0073039, theta=-16.452055 -> V=1.0, theta=0.0
% INFO    : Bus 209	: V=1.0061008, theta=-16.612354 -> V=1.0, theta=0.0
% INFO    : Bus 210	: V=1.0030885, theta=-12.198675 -> V=1.0, theta=0.0
% INFO    : Bus 211	: V=1.0025107, theta=-12.269021 -> V=1.0, theta=0.0
% INFO    : Bus 212	: V=1.0200216, theta=-14.860628 -> V=1.0, theta=0.0
% INFO    : Bus 213	: V=1.0184746, theta=-15.049764 -> V=1.0, theta=0.0
% INFO    : Bus 214	: V=1.0038818, theta=-14.888695 -> V=1.0, theta=0.0
% INFO    : Bus 215	: V=1.0025328, theta=-15.064666 -> V=1.0, theta=0.0
% INFO    : Bus 216	: V=0.9909531, theta=-15.191861 -> V=1.0, theta=0.0
% INFO    : Bus 217	: V=0.9901535, theta=-15.287399 -> V=1.0, theta=0.0
% INFO    : Bus 218	: V=1.0265297, theta=-15.614815 -> V=1.0, theta=0.0
% INFO    : Bus 219	: V=1.0265246, theta=-15.615449 -> V=1.0, theta=0.0
% INFO    : Bus 220	: V=1.0358491, theta=-3.894841 -> V=1.0, theta=0.0
% INFO    : Bus 221	: V=1.0199749, theta=-7.173621 -> V=1.0, theta=0.0
% INFO    : Bus 222	: V=1.0363015, theta=-3.833602 -> V=1.0, theta=0.0
% INFO    : Bus 223	: V=1.0379743, theta=-3.603247 -> V=1.0, theta=0.0
% INFO    : Bus 224	: V=1.04, theta=-0.630202 -> V=1.0, theta=0.0
% INFO    : Bus 225	: V=1.04, theta=-2.197638 -> V=1.0, theta=0.0
% INFO    : Bus 226	: V=1.0121488, theta=-7.685244 -> V=1.0, theta=0.0
% INFO    : Bus 227	: V=1.0120652, theta=-7.694859 -> V=1.0, theta=0.0
% INFO    : Bus 228	: V=1.0007991, theta=-10.084482 -> V=1.0, theta=0.0
% INFO    : Bus 229	: V=0.9999607, theta=-10.190763 -> V=1.0, theta=0.0
% INFO    : Bus 230	: V=1.0106816, theta=-12.800754 -> V=1.0, theta=0.0
% INFO    : Bus 231	: V=1.0132903, theta=-12.497264 -> V=1.0, theta=0.0
% INFO    : Bus 232	: V=1.0291859, theta=-8.750481 -> V=1.0, theta=0.0
% INFO    : Bus 233	: V=1.0189285, theta=-12.07566 -> V=1.0, theta=0.0
% INFO    : Bus 234	: V=1.0180658, theta=-12.183893 -> V=1.0, theta=0.0
% INFO    : Bus 235	: V=1.0297044, theta=-12.607399 -> V=1.0, theta=0.0
% INFO    : Bus 236	: V=1.0223514, theta=-13.837274 -> V=1.0, theta=0.0
% INFO    : Bus 237	: V=1.0223092, theta=-13.841976 -> V=1.0, theta=0.0
% INFO    : Bus 238	: V=1.0159596, theta=-11.79559 -> V=1.0, theta=0.0
% INFO    : Bus 239	: V=1.0153893, theta=-11.871265 -> V=1.0, theta=0.0
% INFO    : Bus 240	: V=1.0231089, theta=-16.558732 -> V=1.0, theta=0.0
% INFO    : Bus 241	: V=1.0227994, theta=-16.600225 -> V=1.0, theta=0.0
% INFO    : Bus 242	: V=1.0199506, theta=-15.952274 -> V=1.0, theta=0.0
% INFO    : Bus 243	: V=1.0187828, theta=-16.097661 -> V=1.0, theta=0.0
% INFO    : Bus 244	: V=1.0080457, theta=-13.013874 -> V=1.0, theta=0.0
% INFO    : Bus 245	: V=1.0078768, theta=-13.033852 -> V=1.0, theta=0.0
% INFO    : Bus 246	: V=1.0315679, theta=-7.569362 -> V=1.0, theta=0.0
% INFO    : Bus 247	: V=1.02609, theta=-6.866485 -> V=1.0, theta=0.0
% INFO    : Bus 248	: V=1.0315679, theta=-7.569362 -> V=1.0, theta=0.0
% INFO    : Bus 249	: V=1.0315679, theta=-7.569362 -> V=1.0, theta=0.0
% INFO    : Bus 250	: V=1.0315679, theta=-7.569362 -> V=1.0, theta=0.0
% INFO    : Bus 251	: V=0.9904267, theta=-14.766683 -> V=1.0, theta=0.0
% INFO    : Bus 252	: V=0.9883863, theta=-15.022792 -> V=1.0, theta=0.0
% INFO    : Bus 253	: V=0.9906966, theta=-14.794733 -> V=1.0, theta=0.0
% INFO    : Bus 254	: V=0.9906966, theta=-14.794733 -> V=1.0, theta=0.0
% INFO    : Bus 255	: V=0.9906966, theta=-14.794733 -> V=1.0, theta=0.0
% INFO    : Bus 256	: V=0.9906966, theta=-14.794733 -> V=1.0, theta=0.0
% INFO    : Bus 257	: V=0.9906966, theta=-14.794733 -> V=1.0, theta=0.0
% INFO    : Bus 258	: V=0.9921359, theta=-14.631266 -> V=1.0, theta=0.0
% INFO    : Bus 259	: V=0.9905642, theta=-14.810955 -> V=1.0, theta=0.0
% INFO    : Bus 260	: V=1.0255132, theta=-4.808914 -> V=1.0, theta=0.0
% INFO    : Bus 261	: V=1.0252472, theta=-4.841116 -> V=1.0, theta=0.0
% INFO    : Bus 262	: V=1.028499, theta=-9.027102 -> V=1.0, theta=0.0
% INFO    : Bus 263	: V=1.0224478, theta=-13.257732 -> V=1.0, theta=0.0
% INFO    : Bus 264	: V=1.028499, theta=-9.027102 -> V=1.0, theta=0.0
% INFO    : Bus 265	: V=1.028499, theta=-9.027102 -> V=1.0, theta=0.0
% INFO    : Bus 266	: V=1.0215515, theta=-13.367998 -> V=1.0, theta=0.0
% INFO    : Bus 267	: V=1.0158874, theta=-18.246617 -> V=1.0, theta=0.0
% INFO    : Bus 268	: V=1.0141983, theta=-18.470761 -> V=1.0, theta=0.0
% INFO    : Bus 269	: V=1.0156147, theta=-7.283146 -> V=1.0, theta=0.0
% INFO    : Bus 270	: V=1.0155052, theta=-7.297592 -> V=1.0, theta=0.0
% INFO    : Bus 271	: V=1.0290681, theta=-12.796963 -> V=1.0, theta=0.0
% INFO    : Bus 272	: V=1.0236391, theta=-14.539826 -> V=1.0, theta=0.0
% INFO    : Bus 273	: V=1.0234875, theta=-14.559791 -> V=1.0, theta=0.0
% INFO    : Bus 274	: V=1.0261895, theta=-5.713892 -> V=1.0, theta=0.0
% INFO    : Bus 275	: V=1.0261895, theta=-5.713892 -> V=1.0, theta=0.0
% INFO    : Bus 276	: V=1.0169299, theta=-13.764542 -> V=1.0, theta=0.0
% INFO    : Bus 277	: V=1.0169239, theta=-13.765331 -> V=1.0, theta=0.0
% INFO    : Bus 278	: V=1.0168416, theta=-13.776398 -> V=1.0, theta=0.0
% INFO    : Bus 279	: V=1.0019521, theta=-11.256427 -> V=1.0, theta=0.0
% INFO    : Bus 280	: V=1.0016961, theta=-11.28445 -> V=1.0, theta=0.0
% INFO    : Bus 281	: V=0.993673, theta=-16.290384 -> V=1.0, theta=0.0
% INFO    : Bus 282	: V=0.9918865, theta=-16.527233 -> V=1.0, theta=0.0
% INFO    : Bus 283	: V=1.0168088, theta=-14.300977 -> V=1.0, theta=0.0
% INFO    : Bus 284	: V=1.016259, theta=-14.370063 -> V=1.0, theta=0.0
% INFO    : Bus 285	: V=1.0092672, theta=-14.564141 -> V=1.0, theta=0.0
% INFO    : Bus 286	: V=1.0091411, theta=-14.578503 -> V=1.0, theta=0.0
% INFO    : Bus 287	: V=1.0143709, theta=-12.57241 -> V=1.0, theta=0.0
% INFO    : Bus 288	: V=1.0134945, theta=-12.691679 -> V=1.0, theta=0.0
% INFO    : Bus 289	: V=1.0180093, theta=-6.49922 -> V=1.0, theta=0.0
% INFO    : Bus 290	: V=1.0179528, theta=-6.506691 -> V=1.0, theta=0.0
% INFO    : Bus 291	: V=1.0074516, theta=-14.210134 -> V=1.0, theta=0.0
% INFO    : Bus 292	: V=1.0073427, theta=-14.22332 -> V=1.0, theta=0.0
% INFO    : Bus 293	: V=1.0189857, theta=-14.975632 -> V=1.0, theta=0.0
% INFO    : Bus 294	: V=1.0186026, theta=-15.019706 -> V=1.0, theta=0.0
% INFO    : Bus 295	: V=1.0098756, theta=-12.116123 -> V=1.0, theta=0.0
% INFO    : Bus 296	: V=1.009764, theta=-12.130528 -> V=1.0, theta=0.0
% INFO    : Bus 297	: V=1.0184798, theta=-10.360935 -> V=1.0, theta=0.0
% INFO    : Bus 298	: V=1.0155302, theta=-11.821268 -> V=1.0, theta=0.0
% INFO    : Bus 299	: V=1.0153135, theta=-11.849521 -> V=1.0, theta=0.0
% INFO    : Bus 300	: V=1.0052551, theta=-4.728173 -> V=1.0, theta=0.0
% INFO    : Bus 301	: V=1.0064142, theta=-4.59659 -> V=1.0, theta=0.0
% INFO    : Bus 302	: V=1.0064104, theta=-4.602319 -> V=1.0, theta=0.0
% INFO    : Bus 303	: V=1.0037703, theta=-4.916585 -> V=1.0, theta=0.0
% INFO    : Bus 304	: V=0.9852103, theta=-15.62793 -> V=1.0, theta=0.0
% INFO    : Bus 305	: V=0.9874891, theta=-15.316977 -> V=1.0, theta=0.0
% INFO    : Bus 306	: V=0.9876508, theta=-15.277575 -> V=1.0, theta=0.0
% INFO    : Bus 307	: V=0.98407, theta=-15.777163 -> V=1.0, theta=0.0
% INFO    : Bus 308	: V=1.0123136, theta=-14.591511 -> V=1.0, theta=0.0
% INFO    : Bus 309	: V=1.0121598, theta=-14.6108 -> V=1.0, theta=0.0
% INFO    : Bus 310	: V=1.0015518, theta=-17.31631 -> V=1.0, theta=0.0
% INFO    : Bus 311	: V=1.0008615, theta=-17.402043 -> V=1.0, theta=0.0
% INFO    : Bus 312	: V=1.0193147, theta=-16.635405 -> V=1.0, theta=0.0
% INFO    : Bus 313	: V=1.0191068, theta=-16.66151 -> V=1.0, theta=0.0
% INFO    : Bus 314	: V=1.00966, theta=-13.041157 -> V=1.0, theta=0.0
% INFO    : Bus 315	: V=1.0096542, theta=-13.041875 -> V=1.0, theta=0.0
% INFO    : Bus 316	: V=1.0193479, theta=-2.817116 -> V=1.0, theta=0.0
% INFO    : Bus 317	: V=1.0192933, theta=-2.823048 -> V=1.0, theta=0.0
% INFO    : Bus 318	: V=1.0214885, theta=-3.719544 -> V=1.0, theta=0.0
% INFO    : Bus 319	: V=1.0335965, theta=-1.991927 -> V=1.0, theta=0.0
% INFO    : Bus 320	: V=1.0098195, theta=-16.112639 -> V=1.0, theta=0.0
% INFO    : Bus 321	: V=1.0074312, theta=-16.405063 -> V=1.0, theta=0.0
% INFO    : Bus 322	: V=0.9971067, theta=-14.270854 -> V=1.0, theta=0.0
% INFO    : Bus 323	: V=0.9964301, theta=-14.347442 -> V=1.0, theta=0.0
% INFO    : Bus 324	: V=0.9880142, theta=-15.476147 -> V=1.0, theta=0.0
% INFO    : Bus 325	: V=0.9864059, theta=-15.693239 -> V=1.0, theta=0.0
% INFO    : Bus 326	: V=1.0140872, theta=-14.946788 -> V=1.0, theta=0.0
% INFO    : Bus 327	: V=1.0123797, theta=-15.152255 -> V=1.0, theta=0.0
% INFO    : Bus 328	: V=0.998439, theta=-12.855872 -> V=1.0, theta=0.0
% INFO    : Bus 329	: V=0.9980834, theta=-12.899052 -> V=1.0, theta=0.0
% INFO    : Bus 330	: V=1.0150802, theta=-10.163426 -> V=1.0, theta=0.0
% INFO    : Bus 331	: V=1.014173, theta=-10.282108 -> V=1.0, theta=0.0
% INFO    : Bus 332	: V=1.0293546, theta=-7.731968 -> V=1.0, theta=0.0
% INFO    : Bus 333	: V=1.0205952, theta=-9.351436 -> V=1.0, theta=0.0
% INFO    : Bus 334	: V=1.0205878, theta=-9.352269 -> V=1.0, theta=0.0
% INFO    : Bus 335	: V=1.0205824, theta=-9.352989 -> V=1.0, theta=0.0
% INFO    : Bus 336	: V=1.0157095, theta=-5.023538 -> V=1.0, theta=0.0
% INFO    : Bus 337	: V=1.0156199, theta=-5.035366 -> V=1.0, theta=0.0
% INFO    : Bus 338	: V=1.0111419, theta=5.201778 -> V=1.0, theta=0.0
% INFO    : Bus 339	: V=1.010004, theta=5.055126 -> V=1.0, theta=0.0
% INFO    : Bus 340	: V=1.0015628, theta=-11.84901 -> V=1.0, theta=0.0
% INFO    : Bus 341	: V=1.0011648, theta=-11.899981 -> V=1.0, theta=0.0
% INFO    : Bus 342	: V=1.0114132, theta=-14.590081 -> V=1.0, theta=0.0
% INFO    : Bus 343	: V=1.0113749, theta=-14.594967 -> V=1.0, theta=0.0
% INFO    : Bus 344	: V=1.0113746, theta=-14.595149 -> V=1.0, theta=0.0
% INFO    : Bus 345	: V=1.0019297, theta=-14.969012 -> V=1.0, theta=0.0
% INFO    : Bus 346	: V=1.0012603, theta=-15.051568 -> V=1.0, theta=0.0
% INFO    : Bus 347	: V=0.9876687, theta=-15.370651 -> V=1.0, theta=0.0
% INFO    : Bus 348	: V=0.98643, theta=-15.521285 -> V=1.0, theta=0.0
% INFO    : Bus 349	: V=1.0194335, theta=-13.420251 -> V=1.0, theta=0.0
% INFO    : Bus 350	: V=1.0238049, theta=-12.839187 -> V=1.0, theta=0.0
% INFO    : Bus 351	: V=1.0215057, theta=-13.155003 -> V=1.0, theta=0.0
% INFO    : Bus 352	: V=1.0237081, theta=-12.859395 -> V=1.0, theta=0.0
% INFO    : Bus 353	: V=1.0398268, theta=-10.572718 -> V=1.0, theta=0.0
% INFO    : Bus 354	: V=1.0221354, theta=-9.207297 -> V=1.0, theta=0.0
% INFO    : Bus 355	: V=1.0218047, theta=-9.246469 -> V=1.0, theta=0.0
% INFO    : Bus 356	: V=1.004616, theta=-17.161342 -> V=1.0, theta=0.0
% INFO    : Bus 357	: V=1.0038006, theta=-17.265129 -> V=1.0, theta=0.0
% INFO    : Bus 358	: V=1.002246, theta=-17.846457 -> V=1.0, theta=0.0
% INFO    : Bus 359	: V=1.0020122, theta=-17.874149 -> V=1.0, theta=0.0
% INFO    : Bus 360	: V=1.0019414, theta=-12.69979 -> V=1.0, theta=0.0
% INFO    : Bus 361	: V=1.0019414, theta=-12.69979 -> V=1.0, theta=0.0
% INFO    : Bus 362	: V=1.0019414, theta=-12.69979 -> V=1.0, theta=0.0
% INFO    : Bus 363	: V=1.0019414, theta=-12.69979 -> V=1.0, theta=0.0
% INFO    : Bus 364	: V=1.0014965, theta=-12.759246 -> V=1.0, theta=0.0
% INFO    : Bus 365	: V=1.0079673, theta=-14.199564 -> V=1.0, theta=0.0
% INFO    : Bus 366	: V=1.007076, theta=-14.319807 -> V=1.0, theta=0.0
% INFO    : Bus 367	: V=1.0139301, theta=-7.747489 -> V=1.0, theta=0.0
% INFO    : Bus 368	: V=1.0137749, theta=-7.767132 -> V=1.0, theta=0.0
% INFO    : Bus 369	: V=1.0178, theta=-6.555578 -> V=1.0, theta=0.0
% INFO    : Bus 370	: V=1.0173144, theta=-6.612943 -> V=1.0, theta=0.0
% INFO    : Bus 371	: V=1.0281619, theta=-8.594057 -> V=1.0, theta=0.0
% INFO    : Bus 372	: V=1.0189188, theta=-12.156325 -> V=1.0, theta=0.0
% INFO    : Bus 373	: V=1.0185138, theta=-12.204496 -> V=1.0, theta=0.0
% INFO    : Bus 374	: V=1.0050895, theta=-14.651216 -> V=1.0, theta=0.0
% INFO    : Bus 375	: V=1.0047681, theta=-14.691594 -> V=1.0, theta=0.0
% INFO    : Bus 376	: V=1.0074299, theta=-11.353657 -> V=1.0, theta=0.0
% INFO    : Bus 377	: V=1.0061712, theta=-11.518213 -> V=1.0, theta=0.0
% INFO    : Bus 378	: V=1.0198953, theta=-4.054195 -> V=1.0, theta=0.0
% INFO    : Bus 379	: V=1.0196904, theta=-4.080449 -> V=1.0, theta=0.0
% INFO    : Bus 380	: V=1.0083401, theta=-10.219292 -> V=1.0, theta=0.0
% INFO    : Bus 381	: V=1.0081907, theta=-10.238987 -> V=1.0, theta=0.0
% INFO    : Bus 382	: V=1.0071327, theta=-17.111746 -> V=1.0, theta=0.0
% INFO    : Bus 383	: V=1.0066878, theta=-17.169775 -> V=1.0, theta=0.0
% INFO    : Bus 384	: V=0.9943399, theta=-14.876752 -> V=1.0, theta=0.0
% INFO    : Bus 385	: V=0.9938205, theta=-14.940378 -> V=1.0, theta=0.0
% INFO    : Bus 386	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 387	: V=1.0206034, theta=-6.487292 -> V=1.0, theta=0.0
% INFO    : Bus 388	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 389	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 390	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 391	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 392	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 393	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 394	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 395	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 396	: V=1.0266234, theta=-4.703693 -> V=1.0, theta=0.0
% INFO    : Bus 397	: V=1.0200567, theta=-6.556841 -> V=1.0, theta=0.0
% INFO    : Bus 398	: V=1.0203535, theta=-6.514238 -> V=1.0, theta=0.0
% INFO    : Bus 399	: V=1.0227196, theta=-14.802415 -> V=1.0, theta=0.0
% INFO    : Bus 400	: V=1.0223247, theta=-14.850123 -> V=1.0, theta=0.0
% INFO    : Bus 401	: V=1.0077629, theta=1.960999 -> V=1.0, theta=0.0
% INFO    : Bus 402	: V=1.0064404, theta=1.782537 -> V=1.0, theta=0.0
% INFO    : Bus 403	: V=1.0124364, theta=-14.144706 -> V=1.0, theta=0.0
% INFO    : Bus 404	: V=1.0121354, theta=-14.181207 -> V=1.0, theta=0.0
% INFO    : Bus 405	: V=1.0044697, theta=-5.351052 -> V=1.0, theta=0.0
% INFO    : Bus 406	: V=1.0043897, theta=-5.361176 -> V=1.0, theta=0.0
% INFO    : Bus 407	: V=1.0342597, theta=-11.148168 -> V=1.0, theta=0.0
% INFO    : Bus 408	: V=1.0278065, theta=-13.272779 -> V=1.0, theta=0.0
% INFO    : Bus 409	: V=1.0342597, theta=-11.148168 -> V=1.0, theta=0.0
% INFO    : Bus 410	: V=1.04, theta=-9.40699 -> V=1.0, theta=0.0
% INFO    : Bus 411	: V=1.04, theta=-10.156419 -> V=1.0, theta=0.0
% INFO    : Bus 412	: V=1.04, theta=-10.01105 -> V=1.0, theta=0.0
% INFO    : Bus 413	: V=1.04, theta=-9.856958 -> V=1.0, theta=0.0
% INFO    : Bus 414	: V=1.0342597, theta=-11.148168 -> V=1.0, theta=0.0
% INFO    : Bus 415	: V=1.0093871, theta=-13.550956 -> V=1.0, theta=0.0
% INFO    : Bus 416	: V=1.0092938, theta=-13.563546 -> V=1.0, theta=0.0
% INFO    : Bus 417	: V=0.9978471, theta=-14.070378 -> V=1.0, theta=0.0
% INFO    : Bus 418	: V=0.9968329, theta=-14.192912 -> V=1.0, theta=0.0
% INFO    : Bus 419	: V=1.0018826, theta=-17.178317 -> V=1.0, theta=0.0
% INFO    : Bus 420	: V=1.0018009, theta=-17.189065 -> V=1.0, theta=0.0
% INFO    : Bus 421	: V=1.0132885, theta=-10.584299 -> V=1.0, theta=0.0
% INFO    : Bus 422	: V=1.0125802, theta=-10.664988 -> V=1.0, theta=0.0
% INFO    : Bus 423	: V=0.9970991, theta=1.131359 -> V=1.0, theta=0.0
% INFO    : Bus 424	: V=0.9943752, theta=0.797135 -> V=1.0, theta=0.0
% INFO    : Bus 425	: V=1.0176383, theta=-10.652534 -> V=1.0, theta=0.0
% INFO    : Bus 426	: V=1.0124489, theta=-13.022588 -> V=1.0, theta=0.0
% INFO    : Bus 427	: V=1.0122373, theta=-13.045554 -> V=1.0, theta=0.0
% INFO    : Bus 428	: V=1.0309744, theta=-7.56871 -> V=1.0, theta=0.0
% INFO    : Bus 429	: V=1.0205632, theta=-9.431673 -> V=1.0, theta=0.0
% INFO    : Bus 430	: V=1.0312223, theta=-7.534706 -> V=1.0, theta=0.0
% INFO    : Bus 431	: V=1.0314335, theta=-7.504134 -> V=1.0, theta=0.0
% INFO    : Bus 432	: V=1.0311189, theta=-7.548232 -> V=1.0, theta=0.0
% INFO    : Bus 433	: V=1.0332749, theta=-7.241961 -> V=1.0, theta=0.0
% INFO    : Bus 434	: V=1.031349, theta=-7.516518 -> V=1.0, theta=0.0
% INFO    : Bus 435	: V=1.0309744, theta=-7.56871 -> V=1.0, theta=0.0
% INFO    : Bus 436	: V=1.0309744, theta=-7.56871 -> V=1.0, theta=0.0
% INFO    : Bus 437	: V=1.04, theta=-5.631093 -> V=1.0, theta=0.0
% INFO    : Bus 438	: V=1.04, theta=-5.134839 -> V=1.0, theta=0.0
% INFO    : Bus 439	: V=1.04, theta=-6.044207 -> V=1.0, theta=0.0
% INFO    : Bus 440	: V=1.0149932, theta=-9.023339 -> V=1.0, theta=0.0
% INFO    : Bus 441	: V=0.9990712, theta=-13.218042 -> V=1.0, theta=0.0
% INFO    : Bus 442	: V=1.0149932, theta=-9.023339 -> V=1.0, theta=0.0
% INFO    : Bus 443	: V=1.0149932, theta=-9.023339 -> V=1.0, theta=0.0
% INFO    : Bus 444	: V=1.0149932, theta=-9.023339 -> V=1.0, theta=0.0
% INFO    : Bus 445	: V=1.0071802, theta=-10.692147 -> V=1.0, theta=0.0
% INFO    : Bus 446	: V=1.0057342, theta=-10.862588 -> V=1.0, theta=0.0
% INFO    : Bus 447	: V=1.0100782, theta=-10.41269 -> V=1.0, theta=0.0
% INFO    : Bus 448	: V=1.0091621, theta=-10.532009 -> V=1.0, theta=0.0
% INFO    : Bus 449	: V=1.0117968, theta=-10.664189 -> V=1.0, theta=0.0
% INFO    : Bus 450	: V=1.0117812, theta=-10.666191 -> V=1.0, theta=0.0
% INFO    : Bus 451	: V=1.0117667, theta=-10.667967 -> V=1.0, theta=0.0
% INFO    : Bus 452	: V=1.0165089, theta=1.254051 -> V=1.0, theta=0.0
% INFO    : Bus 453	: V=1.0311028, theta=-8.886162 -> V=1.0, theta=0.0
% INFO    : Bus 454	: V=1.014943, theta=-13.155392 -> V=1.0, theta=0.0
% INFO    : Bus 455	: V=1.04, theta=-8.316798 -> V=1.0, theta=0.0
% INFO    : Bus 456	: V=1.04, theta=-7.69898 -> V=1.0, theta=0.0
% INFO    : Bus 457	: V=1.0216935, theta=-9.29572 -> V=1.0, theta=0.0
% INFO    : Bus 458	: V=1.0209086, theta=-4.946015 -> V=1.0, theta=0.0
% INFO    : Bus 459	: V=1.0092915, theta=4.724765 -> V=1.0, theta=0.0
% INFO    : Bus 460	: V=1.0040172, theta=-11.735955 -> V=1.0, theta=0.0
% INFO    : Bus 461	: V=1.0023564, theta=-10.684292 -> V=1.0, theta=0.0
% INFO    : Bus 462	: V=1.0187098, theta=-10.043067 -> V=1.0, theta=0.0
% INFO    : Bus 463	: V=1.0187098, theta=-10.043067 -> V=1.0, theta=0.0
% INFO    : Bus 464	: V=1.028482, theta=-7.837284 -> V=1.0, theta=0.0
% INFO    : Bus 465	: V=1.023525, theta=-9.037342 -> V=1.0, theta=0.0
% INFO    : Bus 466	: V=1.0186966, theta=-9.708534 -> V=1.0, theta=0.0
% INFO    : Bus 467	: V=1.014575, theta=-7.869875 -> V=1.0, theta=0.0
% INFO    : Bus 468	: V=1.0037409, theta=-10.647447 -> V=1.0, theta=0.0
% INFO    : Bus 469	: V=0.9913577, theta=-14.32762 -> V=1.0, theta=0.0
% INFO    : Bus 470	: V=1.0158225, theta=-7.464265 -> V=1.0, theta=0.0
% INFO    : Bus 471	: V=1.0293341, theta=-7.522043 -> V=1.0, theta=0.0
% INFO    : Bus 472	: V=1.0219185, theta=-9.072413 -> V=1.0, theta=0.0
% INFO    : Bus 473	: V=1.0163337, theta=-7.004659 -> V=1.0, theta=0.0
% INFO    : Bus 474	: V=0.9844776, theta=-14.668767 -> V=1.0, theta=0.0
% INFO    : Bus 475	: V=1.0165032, theta=-7.956363 -> V=1.0, theta=0.0
% INFO    : Bus 476	: V=1.0169559, theta=-13.407146 -> V=1.0, theta=0.0
% INFO    : Bus 477	: V=1.0113153, theta=-11.599347 -> V=1.0, theta=0.0
% INFO    : Bus 478	: V=1.015542, theta=-6.637314 -> V=1.0, theta=0.0
% INFO    : Bus 479	: V=1.0334153, theta=-7.521542 -> V=1.0, theta=0.0
% INFO    : Bus 480	: V=1.04, theta=-5.651627 -> V=1.0, theta=0.0
% INFO    : Bus 481	: V=1.04, theta=-6.207739 -> V=1.0, theta=0.0
% INFO    : Bus 482	: V=1.0391502, theta=-6.768881 -> V=1.0, theta=0.0
% INFO    : Bus 483	: V=1.04, theta=-6.244836 -> V=1.0, theta=0.0
% INFO    : Bus 484	: V=1.0393831, theta=-6.71006 -> V=1.0, theta=0.0
% INFO    : Bus 485	: V=1.01206, theta=-13.993949 -> V=1.0, theta=0.0
% INFO    : Bus 486	: V=1.0151223, theta=-13.130199 -> V=1.0, theta=0.0
% INFO    : Bus 487	: V=1.009396, theta=-16.501663 -> V=1.0, theta=0.0
% INFO    : Bus 488	: V=0.9922874, theta=-13.986015 -> V=1.0, theta=0.0
% INFO    : Bus 489	: V=1.0202077, theta=-13.841817 -> V=1.0, theta=0.0
% INFO    : Bus 490	: V=0.9978405, theta=-14.657483 -> V=1.0, theta=0.0
% INFO    : Bus 491	: V=1.0166852, theta=-15.052744 -> V=1.0, theta=0.0
% INFO    : Bus 492	: V=1.0039171, theta=-6.026577 -> V=1.0, theta=0.0
% INFO    : Bus 493	: V=1.0137292, theta=-8.72548 -> V=1.0, theta=0.0
% INFO    : Bus 494	: V=1.0137292, theta=-8.72548 -> V=1.0, theta=0.0
% INFO    : Bus 495	: V=1.0092486, theta=-11.042696 -> V=1.0, theta=0.0
% INFO    : Bus 496	: V=1.0125171, theta=4.990209 -> V=1.0, theta=0.0
% INFO    : Bus 497	: V=1.0271946, theta=7.110603 -> V=1.0, theta=0.0
% INFO    : Bus 498	: V=1.0209749, theta=6.147677 -> V=1.0, theta=0.0
% INFO    : Bus 499	: V=1.0034375, theta=-15.286762 -> V=1.0, theta=0.0
% INFO    : Bus 500	: V=1.0168639, theta=-13.971591 -> V=1.0, theta=0.0
% INFO    : 
% INFO    : === Generator Setpoint Replacement Notes ===
% INFO    : Gen at bus 9	: Pg=771.8, Qg=105.75 -> Pg=501.67, Qg=132.75
% INFO    : Gen at bus 16	: Pg=444.45, Qg=84.69 -> Pg=288.89, Qg=63.56
% INFO    : Gen at bus 17	: Pg=888.9, Qg=150.17 -> Pg=577.785, Qg=127.115
% INFO    : Gen at bus 18	: Pg=157.6, Qg=21.68 -> Pg=102.44, Qg=22.54
% INFO    : Gen at bus 49	: Pg=1.3, Qg=0.61 -> Pg=0.845, Qg=0.225
% INFO    : Gen at bus 50	: Pg=2.6, Qg=1.21 -> Pg=1.69, Qg=0.445
% INFO    : Gen at bus 63	: Pg=0.0, Qg=0.0 -> Pg=2.08, Qg=0.635
% INFO    : Gen at bus 71	: Pg=4.0, Qg=1.54 -> Pg=2.6, Qg=0.67
% INFO    : Gen at bus 72	: Pg=2.0, Qg=0.77 -> Pg=1.3, Qg=0.335
% INFO    : Gen at bus 73	: Pg=1.4, Qg=0.54 -> Pg=0.91, Qg=0.235
% INFO    : Gen at bus 82	: Pg=361.9, Qg=41.13 -> Pg=235.235, Qg=60.62
% INFO    : Gen at bus 125	: Pg=0.0, Qg=0.0 -> Pg=105.3, Qg=27.135
% INFO    : Gen at bus 126	: Pg=0.0, Qg=0.0 -> Pg=105.3, Qg=27.135
% INFO    : Gen at bus 127	: Pg=162.0, Qg=26.1 -> Pg=105.3, Qg=27.135
% INFO    : Gen at bus 128	: Pg=162.0, Qg=62.21 -> Pg=105.3, Qg=27.135
% INFO    : Gen at bus 144	: Pg=602.55, Qg=111.6 -> Pg=391.655, Qg=86.165
% INFO    : Gen at bus 145	: Pg=300.55, Qg=127.35 -> Pg=391.655, Qg=86.165
% INFO    : Gen at bus 167	: Pg=193.5, Qg=45.92 -> Pg=125.775, Qg=32.41
% INFO    : Gen at bus 168	: Pg=193.5, Qg=32.78 -> Pg=125.775, Qg=32.41
% INFO    : Gen at bus 169	: Pg=387.0, Qg=51.63 -> Pg=251.55, Qg=64.825
% INFO    : Gen at bus 197	: Pg=293.6, Qg=43.37 -> Pg=190.84, Qg=50.5
% INFO    : Gen at bus 198	: Pg=207.3, Qg=52.65 -> Pg=134.745, Qg=35.655
% INFO    : Gen at bus 222	: Pg=5.2, Qg=2.0 -> Pg=3.38, Qg=0.875
% INFO    : Gen at bus 223	: Pg=18.0, Qg=6.91 -> Pg=11.7, Qg=3.015
% INFO    : Gen at bus 224	: Pg=511.2, Qg=40.11 -> Pg=332.28, Qg=85.625
% INFO    : Gen at bus 225	: Pg=514.8, Qg=69.67 -> Pg=334.62, Qg=86.225
% INFO    : Gen at bus 231	: Pg=2.9, Qg=1.35 -> Pg=1.885, Qg=0.5
% INFO    : Gen at bus 248	: Pg=0.0, Qg=0.0 -> Pg=86.58, Qg=26.505
% INFO    : Gen at bus 249	: Pg=0.0, Qg=0.0 -> Pg=86.58, Qg=26.505
% INFO    : Gen at bus 250	: Pg=0.0, Qg=0.0 -> Pg=346.32, Qg=106.03
% INFO    : Gen at bus 254	: Pg=0.0, Qg=0.0 -> Pg=2.665, Qg=0.705
% INFO    : Gen at bus 255	: Pg=0.0, Qg=0.0 -> Pg=2.145, Qg=0.57
% INFO    : Gen at bus 256	: Pg=0.0, Qg=0.0 -> Pg=1.885, Qg=0.5
% INFO    : Gen at bus 257	: Pg=0.0, Qg=0.0 -> Pg=3.51, Qg=0.93
% INFO    : Gen at bus 258	: Pg=1.1, Qg=0.51 -> Pg=0.715, Qg=0.19
% INFO    : Gen at bus 264	: Pg=0.0, Qg=0.0 -> Pg=25.48, Qg=7.8
% INFO    : Gen at bus 265	: Pg=0.0, Qg=0.0 -> Pg=6.89, Qg=2.11
% INFO    : Gen at bus 275	: Pg=0.0, Qg=0.0 -> Pg=65.78, Qg=20.14
% INFO    : Gen at bus 301	: Pg=2.9, Qg=1.35 -> Pg=1.885, Qg=0.5
% INFO    : Gen at bus 302	: Pg=2.9, Qg=1.35 -> Pg=1.885, Qg=0.5
% INFO    : Gen at bus 305	: Pg=1.0, Qg=0.38 -> Pg=0.65, Qg=0.165
% INFO    : Gen at bus 306	: Pg=2.4, Qg=0.92 -> Pg=1.56, Qg=0.4
% INFO    : Gen at bus 319	: Pg=42.3, Qg=16.24 -> Pg=27.495, Qg=7.085
% INFO    : Gen at bus 350	: Pg=15.0, Qg=5.76 -> Pg=9.75, Qg=2.51
% INFO    : Gen at bus 351	: Pg=6.2, Qg=2.38 -> Pg=4.03, Qg=1.04
% INFO    : Gen at bus 352	: Pg=14.4, Qg=5.53 -> Pg=9.36, Qg=2.41
% INFO    : Gen at bus 353	: Pg=74.0, Qg=28.42 -> Pg=48.1, Qg=12.395
% INFO    : Gen at bus 361	: Pg=0.0, Qg=0.0 -> Pg=1.04, Qg=0.315
% INFO    : Gen at bus 362	: Pg=0.0, Qg=0.0 -> Pg=7.15, Qg=2.19
% INFO    : Gen at bus 363	: Pg=0.0, Qg=0.0 -> Pg=2.08, Qg=0.635
% INFO    : Gen at bus 388	: Pg=0.0, Qg=0.0 -> Pg=6.5, Qg=1.99
% INFO    : Gen at bus 389	: Pg=0.0, Qg=0.0 -> Pg=112.665, Qg=34.495
% INFO    : Gen at bus 390	: Pg=0.0, Qg=0.0 -> Pg=112.665, Qg=34.495
% INFO    : Gen at bus 391	: Pg=0.0, Qg=0.0 -> Pg=112.665, Qg=34.495
% INFO    : Gen at bus 392	: Pg=0.0, Qg=0.0 -> Pg=75.66, Qg=23.165
% INFO    : Gen at bus 393	: Pg=0.0, Qg=0.0 -> Pg=75.66, Qg=23.165
% INFO    : Gen at bus 394	: Pg=0.0, Qg=0.0 -> Pg=75.66, Qg=23.165
% INFO    : Gen at bus 395	: Pg=0.0, Qg=0.0 -> Pg=75.66, Qg=23.165
% INFO    : Gen at bus 396	: Pg=0.0, Qg=0.0 -> Pg=75.66, Qg=23.165
% INFO    : Gen at bus 409	: Pg=0.0, Qg=0.0 -> Pg=65.0, Qg=19.9
% INFO    : Gen at bus 410	: Pg=77.97, Qg=14.91 -> Pg=89.015, Qg=27.255
% INFO    : Gen at bus 411	: Pg=79.43, Qg=25.56 -> Pg=89.015, Qg=27.255
% INFO    : Gen at bus 412	: Pg=79.43, Qg=22.36 -> Pg=89.015, Qg=27.255
% INFO    : Gen at bus 413	: Pg=60.26, Qg=14.63 -> Pg=89.015, Qg=27.255
% INFO    : Gen at bus 414	: Pg=0.0, Qg=0.0 -> Pg=72.215, Qg=22.11
% INFO    : Gen at bus 430	: Pg=1.0, Qg=0.38 -> Pg=0.65, Qg=0.165
% INFO    : Gen at bus 431	: Pg=3.3, Qg=1.27 -> Pg=2.145, Qg=0.555
% INFO    : Gen at bus 432	: Pg=1.2, Qg=0.46 -> Pg=0.78, Qg=0.2
% INFO    : Gen at bus 433	: Pg=6.7, Qg=2.57 -> Pg=4.355, Qg=1.12
% INFO    : Gen at bus 434	: Pg=4.3, Qg=1.65 -> Pg=2.795, Qg=0.72
% INFO    : Gen at bus 435	: Pg=0.0, Qg=0.0 -> Pg=128.05, Qg=33.0
% INFO    : Gen at bus 436	: Pg=0.0, Qg=0.0 -> Pg=128.05, Qg=33.0
% INFO    : Gen at bus 437	: Pg=197.0, Qg=52.73 -> Pg=128.05, Qg=33.0
% INFO    : Gen at bus 438	: Pg=197.0, Qg=40.14 -> Pg=128.05, Qg=33.0
% INFO    : Gen at bus 439	: Pg=197.0, Qg=65.63 -> Pg=128.05, Qg=33.0
% INFO    : Gen at bus 442	: Pg=0.0, Qg=0.0 -> Pg=70.2, Qg=21.49
% INFO    : Gen at bus 443	: Pg=0.0, Qg=0.0 -> Pg=113.75, Qg=34.82
% INFO    : Gen at bus 444	: Pg=0.0, Qg=0.0 -> Pg=2.145, Qg=0.655
% INFO    : Gen at bus 455	: Pg=66.85, Qg=56.51 -> Pg=144.84, Qg=44.345
% INFO    : Gen at bus 456	: Pg=133.7, Qg=55.65 -> Pg=289.685, Qg=88.685
% INFO    : Gen at bus 458	: Pg=109.6, Qg=0.0 -> Pg=71.24, Qg=0.0
% INFO    : Gen at bus 463	: Pg=0.0, Qg=0.0 -> Pg=4.68, Qg=1.24
% INFO    : Gen at bus 480	: Pg=56.0, Qg=9.62 -> Pg=36.4, Qg=9.38
% INFO    : Gen at bus 481	: Pg=45.0, Qg=12.1 -> Pg=29.25, Qg=7.535
% INFO    : Gen at bus 482	: Pg=45.0, Qg=17.28 -> Pg=29.25, Qg=7.535
% INFO    : Gen at bus 483	: Pg=24.0, Qg=6.25 -> Pg=15.6, Qg=4.02
% INFO    : Gen at bus 484	: Pg=28.0, Qg=10.75 -> Pg=18.2, Qg=4.69
% INFO    : Gen at bus 494	: Pg=0.0, Qg=0.0 -> Pg=3.77, Qg=0.995
% INFO    : Gen at bus 497	: Pg=60.0, Qg=23.04 -> Pg=39.0, Qg=10.05
% INFO    : Gen at bus 498	: Pg=18.0, Qg=6.91 -> Pg=11.7, Qg=3.015
% INFO    : 
% INFO    : === Writing Matpower Case File Notes ===
